function pdp = getTDLProfile(delayProfile)
%getTDLProfile TR 38.901 / TS 38.101-4 / TS 38.104 Tapped Delay Line (TDL) channel profiles
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.

%   Note: The delay profiles 'TDLA30', 'TDLB100', 'TDLC300' and 'TDLC60'
%   specify the delay in seconds, rather than normalized delay, and
%   therefore TR 38.901 Section 7.7.3 "Scaling of delays" should not be
%   applied when using the delay profile returned by this function.

%   Copyright 2016-2021 The MathWorks, Inc.
    
    persistent TDL_A TDL_B TDL_C TDL_D TDL_E TDLA30 TDLB100 TDLC300 TDLC60;
    
    if (isempty(TDL_A))
    
        % TR 38.901 Table 7.7.2-1
        TDL_A = [ ...
                 0.0000  -13.4; ...
                 0.3819    0.0; ...
                 0.4025   -2.2; ...
                 0.5868   -4.0; ...
                 0.4610   -6.0; ...
                 0.5375   -8.2; ...
                 0.6708   -9.9; ...
                 0.5750  -10.5; ...
                 0.7618   -7.5; ...
                 1.5375  -15.9; ...
                 1.8978   -6.6; ...
                 2.2242  -16.7; ...
                 2.1718  -12.4; ...
                 2.4942  -15.2; ...
                 2.5119  -10.8; ...
                 3.0582  -11.3; ...
                 4.0810  -12.7; ...
                 4.4579  -16.2; ...
                 4.5695  -18.3; ...
                 4.7966  -18.9; ...
                 5.0066  -16.6; ...
                 5.3043  -19.9; ...
                 9.6586  -29.7; ...
                ];
        
        % TR 38.901 Table 7.7.2-2
        TDL_B = [ ...
                 0.0000    0.0; ...
                 0.1072   -2.2; ...
                 0.2155   -4.0; ...
                 0.2095   -3.2; ...
                 0.2870   -9.8; ...
                 0.2986   -1.2; ...
                 0.3752   -3.4; ...
                 0.5055   -5.2; ...
                 0.3681   -7.6; ...
                 0.3697   -3.0; ...
                 0.5700   -8.9; ...
                 0.5283   -9.0; ...
                 1.1021   -4.8; ...
                 1.2756   -5.7; ...
                 1.5474   -7.5; ...
                 1.7842   -1.9; ...
                 2.0169   -7.6; ...
                 2.8294  -12.2; ...
                 3.0219   -9.8; ...
                 3.6187  -11.4; ...
                 4.1067  -14.9; ...
                 4.2790   -9.2; ...
                 4.7834  -11.3; ...
                ];
        
        % TR 38.901 Table 7.7.2-3
        TDL_C = [ ...
                 0.0000   -4.4; ...
                 0.2099   -1.2; ...
                 0.2219   -3.5; ...
                 0.2329   -5.2; ...
                 0.2176   -2.5; ...
                 0.6366    0.0; ...
                 0.6448   -2.2; ...
                 0.6560   -3.9; ...
                 0.6584   -7.4; ...
                 0.7935   -7.1; ...
                 0.8213  -10.7; ...
                 0.9336  -11.1; ...
                 1.2285   -5.1; ...
                 1.3083   -6.8; ...
                 2.1704   -8.7; ...
                 2.7105  -13.2; ...
                 4.2589  -13.9; ...
                 4.6003  -13.9; ...
                 5.4902  -15.8; ...
                 5.6077  -17.1; ...
                 6.3065  -16.0; ...
                 6.6374  -15.7; ...
                 7.0427  -21.6; ...
                 8.6523  -22.8; ...
                ];
        
        % TR 38.901 Table 7.7.2-4
        TDL_D = [ ...
                 0.0000   -0.2; ...
                 0.0000  -13.5; ...
                 0.0350  -18.8; ...
                 0.6120  -21.0; ...
                 1.3630  -22.8; ...
                 1.4050  -17.9; ...
                 1.8040  -20.1; ...
                 2.5960  -21.9; ...
                 1.7750  -22.9; ...
                 4.0420  -27.8; ...
                 7.9370  -23.6; ...
                 9.4240  -24.8; ...
                 9.7080  -30.0; ...
                12.5250  -27.7; ...
                ];
        
        % TR 38.901 Table 7.7.2-5
        TDL_E = [ ...
                 0.0000   -0.03; ...
                 0.0000  -22.03; ...
                 0.5133  -15.8; ...
                 0.5440  -18.1; ...
                 0.5630  -19.8; ...
                 0.5440  -22.9; ...
                 0.7112  -22.4; ...
                 1.9092  -18.6; ...
                 1.9293  -20.8; ...
                 1.9589  -22.6; ...
                 2.6426  -22.3; ...
                 3.7136  -25.6; ...
                 5.4524  -20.2; ...
                12.0034  -29.8; ...
                20.6519  -29.2; ...
                ];
        
        % TS 38.101-4 Table B.2.1.1-2
        % TS 38.101-4 Table B.2.1.2-2
        % TS 38.104 Table G.2.1.1-2
        % TS 38.104 Table G.2.1.2-2
        TDLA30 = [ ...
                   0e-9  -15.5; ...
                  10e-9    0.0; ...
                  15e-9   -5.1; ...
                  20e-9   -5.1; ...
                  25e-9   -9.6; ...
                  50e-9   -8.2; ...
                  65e-9  -13.1; ...
                  75e-9  -11.5; ...
                 105e-9  -11.0; ...
                 135e-9  -16.2; ...
                 150e-9  -16.6; ...
                 290e-9  -26.2; ...
                 ];
        
        % TS 38.101-4 Table B.2.1.1-3
        % TS 38.104 Table G.2.1.1-3
        TDLB100 = [ ...
                    0e-9   0.0; ...
                   10e-9  -2.2; ...
                   20e-9  -0.6; ...
                   30e-9  -0.6; ...
                   35e-9  -0.3; ...
                   45e-9  -1.2; ...
                   55e-9  -5.9; ...
                  120e-9  -2.2; ...
                  170e-9  -0.8; ...
                  245e-9  -6.3; ...
                  330e-9  -7.5; ...
                  480e-9  -7.1; ...
                  ];
        
        % TS 38.101-4 Table B.2.1.1-4
        % TS 38.104 Table G.2.1.1-4
        TDLC300 = [ ...
                     0e-9   -6.9; ...
                    65e-9    0.0; ...
                    70e-9   -7.7; ...
                   190e-9   -2.5; ...
                   195e-9   -2.4; ...
                   200e-9   -9.9; ...
                   240e-9   -8.0; ...
                   325e-9   -6.6; ...
                   520e-9   -7.1; ...
                  1045e-9  -13.0; ...
                  1510e-9  -14.2; ...
                  2595e-9  -16.0; ...
                  ];
        
        % TS 38.101-4 Table B.2.1.2-3
        TDLC60 = [ ...
                   0e-9   -7.8; ...
                  15e-9   -0.3; ...
                  40e-9    0.0; ...
                  50e-9   -8.9; ...
                  55e-9  -14.5; ...
                  75e-9   -8.5; ...
                  80e-9  -10.2; ...
                 130e-9  -12.1; ...
                 210e-9  -13.9; ...
                 300e-9  -15.2; ...
                 360e-9  -16.9; ...
                 520e-9  -19.4; ...
                 ];
        
    end
    
    switch (upper(delayProfile))
       
        case 'TDL-A'
            pdp = TDL_A;
        case 'TDL-B'
            pdp = TDL_B;
        case 'TDL-C'
            pdp = TDL_C;
        case 'TDL-D'
            pdp = TDL_D;
        case 'TDL-E'
            pdp = TDL_E;
        case 'TDLA30'
            pdp = TDLA30;
        case 'TDLB100'
            pdp = TDLB100;
        case 'TDLC300'
            pdp = TDLC300;
        case 'TDLC60'
            pdp = TDLC60;
            
    end
    
end
