function [regB, f] = getREGBundles(carrier,pdcch,opts)
%getREGBundles Resource-element group (REG) bundles for PDCCH configuration
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.
%
%   See also nrPDCCHResources, nrPDCCHSpace.

%   Copyright 2019-2021 The MathWorks, Inc.

%#codegen

    % Extract parameter objects
    crst = pdcch.CORESET;

    % Get the CCE-to-REG mapping
    [f,L] = getCCEMapping(crst);

    firstSymLoc = pdcch.SearchSpace.StartSymbolWithinSlot+1;   % 1-based
    symIdx = firstSymLoc(1) + (0:crst.Duration-1);
    
    nStartBWP = double(pdcch.NStartBWP);
    prbIdx = nr5g.internal.pdcch.getCORESETPRB(crst,nStartBWP);

    if strcmpi(opts.IndexOrientation,'carrier')
        rbOffset = nStartBWP - double(carrier.NStartGrid);
        nrb = carrier.NSizeGrid;
    else    % BWP
        rbOffset = 0;
        nrb = pdcch.NSizeBWP;
    end

    % Create RB grid based on BWP, SCS and symbols
    rbGrid = zeros(nrb,carrier.SymbolsPerSlot,'uint32');

    % Place CORESET in grid
    rbGrid(1+prbIdx+rbOffset,symIdx) = 1;

    % Adopt time-first filling in per REG, with freq-first within a REG
    rbIdx = find(rbGrid);
    rbIdxTime = reshape(reshape(rbIdx,[],crst.Duration).',[],1);

    % rbIdxTime are the PRB indices: sort them for CCEs, in REGBundles.
    regB = reshape(rbIdxTime,L,[]);         % form REG-bundles

end