function validatePRACHAndCarrier(carrier, prach)
% Validate the carrier against the PRACH, to check that the two objects
% satisfy TS 38.211 Table 6.3.3.2-1.
%
%    Note: This is an internal undocumented function and its API and/or
%    functionality may change in subsequent releases.
%
%   validatePRACHAndCarrier(CARRIER, PRACH) checks that carrier and prach
%   objects satisfy the constraints given in TS 38.211 Table 6.3.3.2-1.
%   These are related to:
%       * SubcarrierSpacing
%       * Number of carrier RBs allocated for PRACH

%  Copyright 2019-2021 The MathWorks, Inc.

%#codegen

    table = nr5g.internal.prach.getTable6332x(1);
    
    % Find the current combination of SubcarrierSpacing in the table
    comb = table.LRA == prach.LRA & ...
           table.PRACHSubcarrierSpacing == prach.SubcarrierSpacing & ...
           table.PUSCHSubcarrierSpacing == carrier.SubcarrierSpacing;
    
    % Validate the combination of SubcarrierSpacing
    errorFlag = ~any(comb);
    coder.internal.errorIf(errorFlag,'nr5g:nrPRACH:InvalidSCSForPRACHAndCarrier',sprintf('%g',prach.SubcarrierSpacing),sprintf('%g',double(carrier.SubcarrierSpacing)));
    
    % Validate the carrier grid size for the given PRACH
    errorFlag = any(carrier.NSizeGrid < table.NRBAllocation(comb));
    coder.internal.errorIf(errorFlag,'nr5g:nrPRACH:InvalidNRBForPRACHAndCarrier',sprintf('%g',min(table.NRBAllocation(comb))),sprintf('%g',double(carrier.NSizeGrid)));

end
