classdef Format1ConfigBase < nr5g.internal.pucch.CommonConfig ...
        & nr5g.internal.FrequencyHoppingConfig & nr5g.internal.pucch.Formats01Common ...
        & nr5g.internal.pucch.Formats14Common
%Format1ConfigBase Class offering properties common between nrPUCCH1Config
%and nrWavegenPUCCH1Config
%
%   Note: This is an internal undocumented class and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2021 The MathWorks, Inc.

%#codegen

    methods
        % Constructor
        function obj = Format1ConfigBase(varargin)
            % Get the value of SymbolAllocation from the name-value pairs
            symAlloc = nr5g.internal.parseProp('SymbolAllocation',[0 14],varargin{:});
            % Get the value of PRBSet from the name-value pairs
            prbSet = nr5g.internal.parseProp('PRBSet',0,varargin{:});
            % Get the value of HoppingID from the name-value pairs
            hoppingId = nr5g.internal.parseProp('HoppingID',[],varargin{:});

            % Add sets for enum properties with different sized values
            obj = obj@nr5g.internal.pucch.CommonConfig( ...
                'SymbolAllocation', symAlloc, ...
                'PRBSet', prbSet, ...
                'FrequencyHopping', 'neither',...
                'GroupHopping', 'neither', ...
                'HoppingID', hoppingId, ...
                varargin{:});
        end
    end
    
    methods(Access = public)
        % Validate configuration
        function validateConfig(obj)
            % SymbolAllocation(2) must be at least 4, if SymbolAllocation is not empty
            if ~isempty(obj.SymbolAllocation)
                numSymbols = obj.SymbolAllocation(2);
                coder.internal.errorIf(...
                    (numSymbols ~= 0) && (numSymbols < 4),...
                    'nr5g:nrPUCCH:InvalidNumSymbolsLongPUCCH',numSymbols,'1');
            end
            
            % PRBSet must be a scalar, if not empty
            if ~isempty(obj.PRBSet)
                prop = 'PRBSet';
                validateattributes(obj.PRBSet,{'numeric'},{'scalar'},[class(obj) '.' prop],prop);
            end
        end
    end
end