classdef Format2ConfigBase < nr5g.internal.pucch.CommonConfig ...
        & nr5g.internal.FrequencyHoppingConfig & nr5g.internal.pucch.Formats234Common
%Format2ConfigBase Class offering properties common between nrPUCCH2Config
%and nrWavegenPUCCH2Config
%
%   Note: This is an internal undocumented class and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2021 The MathWorks, Inc.

%#codegen

    % Public properties
    properties (SetAccess = 'public')
        %NID0 Scrambling identity for DM-RS
        %   Specify the scrambling identity for demodulation reference
        %   signal (DM-RS) as a scalar nonnegative integer. The value must
        %   be in the range 0...65535. It is the scramblingID0 (0...65535),
        %   if configured, else, it is the physical layer cell identity
        %   (0...1007). Use empty ([]) to make this property equal to the
        %   NCellID property of the carrier configuration object. The
        %   default value is [].
        NID0 = [];
    end
    
    methods
        % Constructor
        function obj = Format2ConfigBase(varargin)
            % Get the value of SymbolAllocation from the name-value pairs
            symAlloc = nr5g.internal.parseProp('SymbolAllocation',[13 1],varargin{:});
            % Get the value of NID from the name-value pairs
            nid = nr5g.internal.parseProp('NID',[],varargin{:});
            % Get the value of NID0 from the name-value pairs
            nid0 = nr5g.internal.parseProp('NID0',[],varargin{:});

            % Add sets for enum properties with different sized values
            obj = obj@nr5g.internal.pucch.CommonConfig( ...
                'FrequencyHopping', 'neither',...
                'SymbolAllocation', symAlloc, ...
                'NID', nid, ...
                'NID0', nid0, varargin{:});
        end

        % Self-validate and set properties
        function obj = set.NID0(obj,val)
            prop = 'NID0';
            % To allow codegen for varying length in a single function script
            temp = val;
            coder.varsize('temp',[1 1],[1 1]);
            if ~(isnumeric(temp) && isempty(temp))
                validateattributes(temp,{'numeric'},...
                    {'scalar','integer','nonnegative','<=',65535},...
                    [class(obj) '.' prop],prop);
            end
            obj.(prop) = val;
        end
    end
    
    methods(Access = public)
        % Validate configuration
        function validateConfig(obj)
            % SymbolAllocation(2) must be 1 or 2, if SymbolAllocation is not empty
            if ~isempty(obj.SymbolAllocation)
                numSymbols = obj.SymbolAllocation(2);
                coder.internal.errorIf(...
                    (numSymbols ~= 0) && ((numSymbols < 1) || (numSymbols > 2)),...
                    'nr5g:nrPUCCH:InvalidNumSymbolsShortPUCCH',numSymbols,'2');
            end
        end
    end
end