classdef Format3ConfigBase < nr5g.internal.pucch.CommonConfig ...
        & nr5g.internal.FrequencyHoppingConfig & nr5g.internal.pucch.Formats34Common
%Format3ConfigBase Class offering properties common between nrPUCCH3Config
%and nrWavegenPUCCH3Config
%
%   Note: This is an internal undocumented class and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2021 The MathWorks, Inc.

%#codegen
    
    methods
        % Constructor
        function obj = Format3ConfigBase(varargin)
            % Get the value of SymbolAllocation from the name-value pairs
            symAlloc = nr5g.internal.parseProp('SymbolAllocation',[0 14],varargin{:});
            % Get the value of NID from the name-value pairs
            nid = nr5g.internal.parseProp('NID',[],varargin{:});
            % Get the value of HoppingID from the name-value pairs
            hoppingId = nr5g.internal.parseProp('HoppingID',[],varargin{:});

            % Add sets for enum properties with different sized values
            obj = obj@nr5g.internal.pucch.CommonConfig( ...
                'Modulation', 'QPSK',  ...
                'SymbolAllocation', symAlloc, ...
                'FrequencyHopping', 'neither',...
                'GroupHopping', 'neither', ...
                'HoppingID', hoppingId, ...
                'NID', nid, ...
                varargin{:});
        end
    end
    
    methods(Access = public)
        % Validate configuration
        function validateConfig(obj)
            % SymbolAllocation(2) must be at least 4, if SymbolAllocation is not empty
            if ~isempty(obj.SymbolAllocation)
                numSymbols = obj.SymbolAllocation(2);
                coder.internal.errorIf(...
                    (numSymbols ~= 0) && (numSymbols < 4),...
                    'nr5g:nrPUCCH:InvalidNumSymbolsLongPUCCH',numSymbols,'3');
            end
        end
    end
end