classdef Format4ConfigBase < nr5g.internal.pucch.CommonConfig ...
        & nr5g.internal.FrequencyHoppingConfig & nr5g.internal.pucch.Formats34Common ...
        & nr5g.internal.pucch.Formats14Common
%Format4ConfigBase Class offering properties common between nrPUCCH4Config
%and nrWavegenPUCCH4Config
%
%   Note: This is an internal undocumented class and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2021 The MathWorks, Inc.

%#codegen

    % Public properties
    properties (SetAccess = 'public')
        %SpreadingFactor Spreading factor
        %   Specify the spreading factor as a scalar positive integer. The
        %   value must be either 2 or 4. The default value is 2.
        SpreadingFactor = 2;
    end
    
    methods
        % Constructor
        function obj = Format4ConfigBase(varargin)
            % Get the value of SymbolAllocation from the name-value pairs
            symAlloc = nr5g.internal.parseProp('SymbolAllocation',[0 14],varargin{:});
            % Get the value of NID from the name-value pairs
            nid = nr5g.internal.parseProp('NID',[],varargin{:});
            % Get the value of HoppingID from the name-value pairs
            hoppingId = nr5g.internal.parseProp('HoppingID',[],varargin{:});

            % Add sets for enum properties with different sized values
            obj = obj@nr5g.internal.pucch.CommonConfig( ...
                'Modulation', 'QPSK',  ...
                'SymbolAllocation', symAlloc, ...
                'FrequencyHopping', 'neither',...
                'GroupHopping', 'neither', ...
                'HoppingID', hoppingId, ...
                'NID', nid, ...
                varargin{:});
        end

        % Self-validate and set properties
        function obj = set.SpreadingFactor(obj,val)
            prop = 'SpreadingFactor';
            validateattributes(val, {'numeric'}, ...
                {'real','scalar'}, ...
                [class(obj) '.' prop], prop);
            coder.internal.errorIf(~any(val == [2 4]),...
                'nr5g:nrPUCCH:InvalidSF',sprintf('%g',double(val)));
            obj.(prop) = val;
        end
    end
    
    methods(Access = public)
        % Validate configuration
        function validateConfig(obj)
            % SymbolAllocation(2) must be at least 4, if SymbolAllocation is not empty
            if ~isempty(obj.SymbolAllocation)
                numSymbols = obj.SymbolAllocation(2);
                coder.internal.errorIf(...
                    (numSymbols ~= 0) && (numSymbols < 4),...
                    'nr5g:nrPUCCH:InvalidNumSymbolsLongPUCCH',numSymbols,'4');
            end
            
            % PRBSet must be a scalar, if not empty
            if ~isempty(obj.PRBSet)
                prop = 'PRBSet';
                validateattributes(obj.PRBSet,{'numeric'},{'scalar'},[class(obj) '.' prop],prop);
            end
                
            % OCCI must be less than SpreadingFactor
            coder.internal.errorIf(obj.OCCI >= obj.SpreadingFactor,...
                    'nr5g:nrPUCCH:InvalidOCCIPUCCH4', obj.OCCI, obj.SpreadingFactor);
        end
    end
end