classdef Formats234Common
    %Formats234Common Common configuration object for PUCCH formats 2, 3, and 4
    %
    %   Note: This is an internal undocumented class and its API and/or
    %   functionality may change in subsequent releases.
    %
    %   Formats234Common properties (configurable):
    %
    %   NID  - Data scrambling identity (0...1023) (default [])
    %   RNTI - Radio network temporary identifier (0...65535) (default 1)

    %   Copyright 2020-2021 The MathWorks, Inc.

    %#codegen

    % Public, tunable properties
    properties

        %NID Data scrambling identity
        %   Specify the data scrambling identity as a scalar nonnegative
        %   integer. The value must be in the range 0...1023. It is the
        %   dataScramblingIdentityPUSCH (0...1023), if configured, else it
        %   is the physical layer cell identity (0...1007). Use empty ([])
        %   to make this property equal to the NCellID property of the
        %   carrier configuration object. The default value is [].
        NID = [];

        %RNTI Radio network temporary identifier
        %   Specify the radio network temporary identifier (RNTI) as a
        %   scalar integer in range 0...65535. The default value is 1.
        RNTI = 1;

    end

    methods

        % Self-validate and set properties
        function obj = set.NID(obj,val)
            prop = 'NID';
            % To allow codegen for varying length in a single function script
            temp = val;
            coder.varsize('temp',[1 1],[1 1]);
            if ~(isnumeric(temp) && isempty(temp))
                validateattributes(temp,{'numeric'},...
                    {'scalar','integer','nonnegative','<=',1023},...
                    [class(obj) '.' prop],prop);
            end
            obj.(prop) = temp;
        end

        function obj = set.RNTI(obj,val)
            prop = 'RNTI';
            validateattributes(val, {'numeric'}, ...
                {'scalar','integer','nonnegative','<=',65535}, ...
                [class(obj) '.' prop], prop);
            obj.(prop) = val;
        end

    end

end
