classdef Formats34Common < nr5g.internal.pucch.Formats234Common ...
        & nr5g.internal.pucch.Formats0134Common
    %Formats34Common Common configuration object for PUCCH formats 3 and 4
    %
    %   Note: This is an internal undocumented class and its API and/or
    %   functionality may change in subsequent releases.
    %
    %   Formats34Common properties (configurable):
    %
    %   Modulation       - Modulation scheme ('QPSK' (default), 'pi/2-BPSK')
    %   AdditionalDMRS   - Additional demodulation reference signal (DM-RS)
    %                      configuration flag (0 (default), 1)
    %   NID              - Data scrambling identity (0...1023) (default [])
    %   RNTI             - Radio network temporary identifier (0...65535)
    %                      (default 1)
    %   GroupHopping     - Group hopping configuration
    %                      ('neither' (default), 'enable', 'disable')
    %   HoppingID        - Hopping identity (0...1023) (default [])

    %   Copyright 2020-2021 The MathWorks, Inc.

    %#codegen

    % Public, tunable properties
    properties

        %Modulation Modulation scheme
        %   Specify the modulation scheme as one of {'pi/2-BPSK', 'QPSK'}.
        %   The default value is 'QPSK'.
        Modulation = 'QPSK';

        %AdditionalDMRS Additional DM-RS configuration flag
        %   Specify the additional demodulation reference signal (DM-RS)
        %   configuration as a numeric or logical scalar. The value is
        %   either true (1) or false (0), provided by higher-layer
        %   parameter, additionalDMRS. This property is used only if the
        %   number of OFDM symbols allocated for physical uplink control
        %   channel is greater than 9. If the value is set to 1, there are
        %   4 DM-RS OFDM symbols. If the value is set to 0, there are 2
        %   DM-RS OFDM symbols. The default value is 0.
        AdditionalDMRS = 0;

    end

    properties(Constant, Hidden)
        Modulation_Values = {'QPSK', 'pi/2-BPSK'};
    end

    methods

        % Self-validate and set properties
        function obj = set.Modulation(obj,val)
            prop = 'Modulation';
            val = validatestring(val,obj.Modulation_Values,...
                [class(obj) '.' prop],prop);
            obj.(prop) = '';
            obj.(prop) = val;
        end

        function obj = set.AdditionalDMRS(obj,val)
            prop = 'AdditionalDMRS';
            validateattributes(val,{'numeric','logical'},...
                {'real','scalar'},...
                [class(obj) '.' prop],prop);
            coder.internal.errorIf(~any(val == [0 1]),...
                'nr5g:nrPUCCH:InvalidAdditionalDMRS',sprintf('%g',double(val)));
            obj.(prop) = val;
        end

    end

end
