function sym = dmrsFormat2(carrier,pucch)
%dmrsFormat2 DM-RS symbols for PUCCH format 2
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.
%
%   SYM = dmrsFormat2(CARRIER,PUCCH) returns the demodulation reference
%   signal (DM-RS) symbols, SYM, of physical uplink control channel format 2,
%   given the carrier configuration CARRIER and physical uplink control
%   channel configuration for format 2, PUCCH. CARRIER is a nrCarrierConfig
%   object. PUCCH is a nrPUCCH2Config object.

%   Copyright 2020 The MathWorks, Inc.

%#codegen

    % OFDM symbol locations
    symAllocation = double(pucch.SymbolAllocation);
    lastPUCCHSym = symAllocation(1) + symAllocation(2) - 1;
    nsym = symAllocation(1):lastPUCCHSym;

    % Relative slot number
    nslot = mod(double(carrier.NSlot),carrier.SlotsPerFrame);

    % DM-RS scrambling identity
    if isempty(pucch.NID0)
        nid0 = double(carrier.NCellID);
    else
        nid0 = double(pucch.NID0(1));
    end

    % Get the set of physical resource blocks
    prbset = unique(reshape(double(pucch.PRBSet),1,[]));

    % Get the set of physical resource blocks for each hop depending on
    % frequency hopping configuration
    prbsetHop = nr5g.internal.prbSetTwoHops(...
        prbset,pucch.FrequencyHopping,pucch.SecondHopStartPRB,nslot);

    % Get the number of unique resource blocks
    numPRB = numel(prbset);

    % Get the resource block offset
    if isempty(pucch.NStartBWP)
        rbOffset = double(carrier.NStartGrid);
    else
        rbOffset = double(pucch.NStartBWP(1));
    end

    % Get spreading sequence
    sf = 1;
    nRE = 4/sf;
    wn = ones(1,numPRB);
    oSeq = reshape(repmat(wn,nRE,1),[],sf);

    % Get DM-RS symbols for first OFDM symbol and apply spreading sequence
    dmrs1 = nr5g.internal.prbsDMRSSequence(struct('NIDNSCID',nid0,'NSCID',0),...
        nRE,prbsetHop(1,:),rbOffset,nslot,nsym(1),carrier.SymbolsPerSlot);
    dmrsSpreadSeq1 = repmat(dmrs1,1,sf).*oSeq;

    if length(nsym) == 2
        % Get DM-RS symbols for second OFDM symbol and apply spreading sequence
        dmrs2 = nr5g.internal.prbsDMRSSequence(struct('NIDNSCID',nid0,'NSCID',0),...
            nRE,prbsetHop(2,:),rbOffset,nslot,nsym(2),carrier.SymbolsPerSlot);
        dmrsSpreadSeq2 = repmat(dmrs2,1,sf).*oSeq;

        % DM-RS symbols in each OFDM symbol
        sym = [reshape(dmrsSpreadSeq1.',[],1) reshape(dmrsSpreadSeq2.',[],1)];
    else
        sym = reshape(dmrsSpreadSeq1.',[],1);
    end

end
