function sym = dmrsFormats34(carrier,pucch,flag)
%dmrsFormats34 DM-RS symbols for PUCCH format 3 and 4
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.
%
%   SYM = dmrsFormat34(CARRIER,PUCCH,FLAG) returns the demodulation
%   reference signal (DM-RS) symbols, SYM, of physical uplink control
%   channel format 3 or 4, given the carrier configuration CARRIER and
%   physical uplink control channel configuration, PUCCH, for format 3 or
%   4. CARRIER is a nrCarrierConfig object. PUCCH is a nrPUCCH3Config or a
%   nrPUCCH4Config object. FLAG is an optional input indicating the
%   inclusion of spreading factor and orthogonal cover code index in the
%   calculation of initial cyclic shift. FLAG is always 1 for PUCCH format 4.

%   Copyright 2020 The MathWorks, Inc.

%#codegen

    % Number of subcarriers allocated for PUCCH
    msc = numel(unique(pucch.PRBSet(:)))*12;

    % Get the DM-RS OFDM symbol locations
    intraSlotFreqHopping = strcmpi(pucch.FrequencyHopping,'intraSlot');
    ldmrs = nr5g.internal.pucch.dmrsSymbolIndicesFormats34(...
        double(pucch.SymbolAllocation),intraSlotFreqHopping,pucch.AdditionalDMRS);

    % Relative slot number
    nslot = mod(double(carrier.NSlot),carrier.SlotsPerFrame);

    % Hopping identity
    if isempty(pucch.HoppingID)
        nid = double(carrier.NCellID);
    else
        nid = double(pucch.HoppingID(1));
    end

    % Get the cyclic shift index
    if isa(pucch,'nrPUCCH4Config') || ((nargin == 3) && flag)
        sf = double(pucch.SpreadingFactor);
        occi = double(pucch.OCCI);
        if sf == 2
            csTable = [0 6];
        else
            csTable = [0 6 3 9];
        end
        initialCS = csTable(1,occi+1);
    else
        initialCS = 0;
    end

    % Get the PUCCH hopping information
    seqCS = 0;
    info = nrPUCCHHoppingInfo(carrier.CyclicPrefix,nslot,nid,pucch.GroupHopping,...
        initialCS,seqCS);

    % Get the number of OFDM symbols allocated for DM-RS in first hop
    numDMRS = length(ldmrs);
    if intraSlotFreqHopping
        nSF0 = floor(numDMRS/2);
    else
        nSF0 = numDMRS;
    end

    % Get the DM-RS symbols with low-PAPR type 1 sequence
    lps1 = nrLowPAPRS(info.U(1),info.V(1),info.Alpha(ldmrs(1:nSF0)+1),msc);
    if intraSlotFreqHopping
        lps2 = nrLowPAPRS(info.U(2),info.V(2),info.Alpha(ldmrs(nSF0+1:end)+1),msc);
        sym = [lps1 lps2];
    else
        sym = lps1;
    end

end
