classdef EnablePower
%EnablePower Class offering 2 common knobs to class extensions for waveform generation 
%
%   Note: This is an internal undocumented class and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2020 The MathWorks, Inc.

%#codegen

    % Public properties
    properties (SetAccess = 'public')

        %Enable Flag to turn channel or signal on or off in waveform generation
        % Specify Enable as a logical scalar. This flag determines the
        % presence of this channel or signal in the generated 5G waveform. The
        % default is true.
        Enable = true;

        %Power Power scaling in dB
        % Specify Power in dB as a real scalar that expresses the amount by
        % which this channel or signal is scaled. The default is 0 dB.
        Power = 0;
    end

    methods
        function obj = set.Enable(obj,val)
            prop = 'Enable';
            obj.(prop) = setEnable(obj, prop, val);
        end

        function obj = set.Power(obj,val)
            prop = 'Power';
            validateattributes(val, {'double'}, {'scalar', 'real', 'finite'}, ...
                [class(obj) '.' prop], prop);
            obj.(prop) = val;
        end
    end
    
    methods (Access=protected)
        % Set and validate any Enable* property
        function out = setEnable(obj, prop, val)
            validateattributes(val, {'logical', 'numeric'}, {'scalar', 'real', 'nonnan'}, ...
                [class(obj) '.' prop], prop);
            out = logical(val);
        end
    end
end
