classdef PXSCHConfigBase < nr5g.internal.wavegen.PXYCHConfigBase & ...
                           nr5g.internal.wavegen.DataSourceCommon & ...
                           nr5g.internal.wavegen.DMRSPowerCommon
    %PXSCHConfigBase Class offering properties common between
    %nrWavegenPDSCHConfig and nrWavegenPUSCHConfig
    %
    %   Note: This is an internal undocumented class and its API and/or
    %   functionality may change in subsequent releases.
    %
    %   PXSCHConfigBase properties (configurable):
    %
    %   Coding     - Flag to enable transport channel coding (default true)
    %   XOverhead  - Rate matching overhead (default 0)
    %   DataSource - Source of transport block contents (default 'PN9-ITU')

    %   Copyright 2020-2021 The MathWorks, Inc.

    %#codegen
    
    % Public, tunable properties
    properties
        %Coding Flag to enable transport channel coding
        % Specify Coding as a scalar logical. Setting Coding to true
        % enables transport channel coding. The default is true.
        Coding = true;
        
        %XOverhead Rate matching overhead
        % Specify XOverhead as one of {0, 6, 12, 18}. This property applies
        % when Coding is true. The default is 0.
        XOverhead = 0;
        
        %DataSource Source of transport block contents
        % Specify DataSource as one of {'PN9-ITU', 'PN9', 'PN11', 'PN15',
        % 'PN23'}, as a cell array containing one of the abovementioned
        % options and a numeric scalar that is the random seed (for example,
        % {'PN9',7}), or as a binary vector. If the seed is not specified,
        % then all shift registers are initialized with an active state.
        % The default is 'PN9-ITU'.
        DataSource = 'PN9-ITU';
    end
    
    % Constant, hidden properties
    properties (Constant,Hidden)
        DataSource_Values = nr5g.internal.wavegen.DataSourceCommon.DataSource_Options;
    end
    
    % Set properties
    methods
        function obj = set.Coding(obj,val)
            prop = 'Coding';
            validateattributes(val, {'logical', 'numeric'}, {'scalar', 'nonnan'}, ...
                [class(obj) '.' prop], prop);
            obj.(prop) = logical(val);
        end
        
        function obj = set.XOverhead(obj,val)
            prop = 'XOverhead';
            validateattributes(val, {'numeric'}, ...
                {'real','scalar'}, ...
                [class(obj) '.' prop], prop);
            coder.internal.errorIf(~any(val==[0 6 12 18]), ...
                'nr5g:nrWaveformGenerator:InvalidXOverhead', sprintf('%g',double(val)));
            obj.(prop) = val;
        end
        
        function obj = set.DataSource(obj,val)
            prop = 'DataSource';
            temp = getDataSource(obj, prop, val);
            obj.(prop) = temp;
        end
    end
    
    methods (Access=protected)
        % Controls the conditional display of properties
        function flag = isInactiveProperty(obj, prop)
            flag = false;
            
            % XOverhead and RVSequence only if Coding is 1
            if any(strcmp(prop,{'XOverhead', 'RVSequence'}))
                flag = ~obj.Coding;
            end
            
            % PTRS and PTRSPower only if EnablePTRS is 1
            if any(strcmp(prop,{'PTRS', 'PTRSPower'}))
                flag = ~obj.EnablePTRS;
            end
        end
    end
end
