function sp = expandbyperiod(in,period,nsf,scs)
% Expand 'in' values with respect to 'period', up to value 'nsf' (optionally accounting for the SCS)

%   Copyright 2019-2020 The MathWorks, Inc.

%#codegen

    if nargin > 3
        % Expand in by period for ts length
        ts = nsf*1*fix(scs/15);
    else
        ts = nsf;
    end
    % Only consider unique values of the input in
    if ~isempty(in)
        tmpIn = unique(in(:));
    else
        tmpIn = in(:); % for codegen
    end
    % Is the period is empty then the pattern doesn't repeat, so doesn't need extending
    if isempty(period)
        tmp = tmpIn;
    else
      % This code can be more compact in MATLAB, but this supports code
      % generation:
      withinPeriod = reshape(tmpIn(tmpIn<period(1)),[],1);
      periodInstances = period(1)*(0:ceil(ts/max(period(1),1))-1);
      tmp = zeros(length(withinPeriod), length(periodInstances));
      for idx1 = 1:length(withinPeriod)
        for idx2 = 1:length(periodInstances)
          tmp(idx1, idx2) = withinPeriod(idx1) + periodInstances(idx2);
        end
      end
    end
    if ~isempty(ts)
      tmp2 = tmp(:); % for codegen
      sp = reshape(tmp2(tmp2 < ts),1,[]); % Trim any excess
    else
      sp = ones(1,0);
    end
end