function table = getFR1BandwidthTable()
% Get transmission bandwidth configuration table for FR1

%   Copyright 2019-2021 The MathWorks, Inc.

    % TS 38.104 Table 5.3.2-1:   Transmission bandwidth configuration NRB for FR1
    % TS 38.101-1 Table 5.3.2-1: Maximum transmission bandwidth configuration NRB (FR1)
    % NRB, for BW and SCS
    % BW MHz    5   10 15 20  25  30  40  50  60  70  80  90  100
    nrbtable = [25  52 79 106 133 160 216 270 NaN NaN NaN NaN NaN;     % 15 kHz
                11  24 38 51  65  78  106 133 162 189 217 245 273;     % 30 kHz
                NaN 11 18 24  31  38  51  65  79  93  107 121 135];    % 60 kHz
    
     % Package NRB array into a table (column names must be valid MATLAB identifiers, thus the BW_ prefix)    
     table = array2table(nrbtable,"RowNames",["15kHz","30kHz","60kHz"],"VariableNames",["BW_5MHz", "BW_10MHz", "BW_15MHz", "BW_20MHz", "BW_25MHz", "BW_30MHz", "BW_40MHz", "BW_50MHz", "BW_60MHz", "BW_70MHz", "BW_80MHz", "BW_90MHz", "BW_100MHz"]);
     table.Properties.Description = 'TS 38.104 Table 5.3.2-1: Transmission bandwidth configuration NRB for FR1';
end
