function table = getFR2BandwidthTable()
% Get transmission bandwidth configuration table for FR2

%   Copyright 2019 The MathWorks, Inc.

    % TS 38.104 Table 5.3.2-2:   Transmission bandwidth configuration NRB for FR2
    % TS 38.101-2 Table 5.3.2-1: Maximum transmission bandwidth configuration NRB (FR2)
    % NRB, for BW and SCS
    % BW MHz    50 100 200 400
    nrbtable = [66  132 264 NaN;   % 60 kHz
                32  66  132 264];  % 120 kHz
     
     % Package NRB array into a table (column names must be valid MATLAB identifiers, thus the BW_ prefix)             
     table = array2table(nrbtable,"RowNames",["60kHz","120kHz"],"VariableNames",["BW_50MHz", "BW_100MHz", "BW_200MHz", "BW_400MHz"]);
     table.Properties.Description = 'TS 38.104 Table 5.3.2-2: Transmission bandwidth configuration NRB for FR2';
end
