function guardband = getGuardband(fr,cbw,scs)
% TS 38.104 Section 5.3.3 
% Minimum guardband and transmission bandwidth configuration

%   Copyright 2019-2020 The MathWorks, Inc.

%#codegen

    % DL: Table 5.3.3-1: Minimum guardband [kHz] (FR1) (TS 38.104)
    % UL: Table 5.3.3-1: Minimum guardband [kHz] (FR1) (TS 38.101-1) 
    cbwFR1    = [    5     10    15     20     25     30     40     50     60     70     80     90    100];
    guardsFR1 = [242.5  312.5 382.5  452.5  522.5  592.5  552.5  692.5    NaN    NaN    NaN    NaN    NaN; ...
                 505.0  665.0 645.0  805.0  785.0  945.0  905.0 1045.0  825.0  965.0  925.0  885.0  845.0; ...
                   NaN 1010.0 990.0 1330.0 1310.0 1290.0 1610.0 1570.0 1530.0 1490.0 1450.0 1410.0 1370.0];
    scsFR1 = [15 30 60].';

    % DL: Table 5.3.3-2: Minimum guardband [kHz] (FR2) (TS 38.104)
    % UL: Table 5.3.3-1: Minimum guardband [kHz] (FR2) (TS 38.101-2) 
    cbwFR2    = [  50  100  200  400];
    guardsFR2 = [1210 2450 4930  NaN; ...
                 1900 2420 4900 9860];
    scsFR2 = [60 120].';
    
    % Return value in MHz
    if (strcmpi(fr,'FR1'))
        guardband = guardsFR1(scsFR1==scs,cbwFR1==cbw) / 1e3;
    else % FR2
        guardband = guardsFR2(scsFR2==scs,cbwFR2==cbw) / 1e3;
    end
    
end