% getNumPorts Calculate the number of ports per BWP required by a component
% carrier configuration cfgObj
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.
%

%   Copyright 2021 The MathWorks, Inc.

%#codegen

function numPorts = getNumPorts(cfgObj)

    isDownlink = isa(cfgObj,'nrDLCarrierConfig');

    if isDownlink
        pxsch = cfgObj.PDSCH;
    else % Uplink
        pxsch = cfgObj.PUSCH;
    end

    % Find numPorts, used in constructions of RE grids in subsequent subfunctions
    enables = nr5g.internal.wavegen.getSinglePropValuesFromCellWithObjects(pxsch, 'Enable', 'logical');
    numlayers = nr5g.internal.wavegen.getSinglePropValuesFromCellWithObjects(pxsch, 'NumLayers', 'double');
    coder.varsize('numlayersEnabled',[1 inf], [0 1]);
    numlayersEnabled = numlayers(enables);
    if isempty(numlayersEnabled)
        maxlayers = 1;
    else
        maxlayers = max(numlayersEnabled);
    end

    bwp = cfgObj.BandwidthParts;
    numPorts = ones(1,numel(bwp))*maxlayers(1);
    
    if isDownlink
        % Update the number of antenna ports corresponding to each BWP
        % based on CSI-RS configuration
        csirs = cfgObj.CSIRS;
        for bwpIdx = 1:numel(bwp)
            for csirsIdx = 1:numel(csirs)
                if bwp{bwpIdx}.BandwidthPartID == csirs{csirsIdx}.BandwidthPartID ...
                        && csirs{csirsIdx}.Enable
                    Ports_Options           = [1 1 2 4 4 8 8 8 12 12 16 16 24 24 24 32 32 32];
                    numCSIRSPorts = Ports_Options(csirs{csirsIdx}.RowNumber);
                    numPorts(bwpIdx) = max([numPorts(bwpIdx) numCSIRSPorts]);
                end
            end
        end
    else
        % Update the number of antenna ports corresponding to each BWP
        % based on SRS configuration
        srs = cfgObj.SRS;
        numPUSCH = numel(pxsch);
        for bwpIdx = 1:numel(bwp)
            n = ones(1,numPUSCH+length(srs));
            for puschIdx = 1:numPUSCH
                if bwp{bwpIdx}.BandwidthPartID == pxsch{puschIdx}.BandwidthPartID && pxsch{puschIdx}.Enable
                    if (strcmpi(pxsch{puschIdx}.TransmissionScheme,'codebook'))
                        n(puschIdx) = pxsch{puschIdx}.NumAntennaPorts;
                    else
                        n(puschIdx) = pxsch{puschIdx}.NumLayers;
                    end
                end
            end
            for srsIdx = 1:numel(srs)
                if bwp{bwpIdx}.BandwidthPartID == srs{srsIdx}.BandwidthPartID && srs{srsIdx}.Enable
                    n(numPUSCH+srsIdx) = srs{srsIdx}.NumSRSPorts;
                end
            end
            maxn = max(n);
            if isempty(maxn) || maxn <= 0
                maxn = 1; % Ensure that there is at least one plane
            end
            numPorts(bwpIdx) = maxn;
        end
    end

end

