function pucchObj = getPUCCHObject(wavePUCCH, formatPUCCH, symbperslot, nch)
%getPUCCHObject Creates nrPUCCHxConfig object
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.
%
%   PUCCHOBJ = getPUCCHObject(WAVEPUCCH,FORMATPUCCH,SYMBPERSLOT,NCH) provides
%   the PUCCH configuration object nrPUCCHxConfig PUCCHOBJ, given the input
%   nrWavegenPUCCHxConfig object WAVEPUCCH, PUCCH format FORMATPUCCH,
%   number of symbols per slot SYMBPERSLOT, and the channel number NCH.

%   Copyright 2021 The MathWorks, Inc.

%#codegen
        
    % Cap the duration (to the max allowed) back to the object, to avoid
    % any OFDM symbols spanning more than one slot
    numSymbols = min(symbperslot-wavePUCCH.SymbolAllocation(1), wavePUCCH.SymbolAllocation(2));
    if numSymbols>=0
        symbolAllocation = [wavePUCCH.SymbolAllocation(1) numSymbols];
    else
        % In the case of extended cyclic prefix, the number of allocated
        % symbols can be negative. In this case, set the symbol allocation
        % to empty.
        symbolAllocation = zeros(0,1);
    end
    
    switch formatPUCCH
        case 0
            pucchObj = nrPUCCH0Config('SymbolAllocation', symbolAllocation);
            commonProps = {'PRBSet','FrequencyHopping','SecondHopStartPRB','InitialCyclicShift','GroupHopping','HoppingID'};
            for idx = 1:length(commonProps)
                pucchObj.(commonProps{idx}) = wavePUCCH.(commonProps{idx});
            end
        case 1
            pucchObj = nrPUCCH1Config('SymbolAllocation', symbolAllocation);
            commonProps = {'PRBSet','FrequencyHopping','SecondHopStartPRB','InitialCyclicShift','GroupHopping','HoppingID','OCCI'};
            for idx = 1:length(commonProps)
                pucchObj.(commonProps{idx}) = wavePUCCH.(commonProps{idx});
            end
        case 2
            pucchObj = nrPUCCH2Config('SymbolAllocation', symbolAllocation, 'PRBSet', unique(wavePUCCH.PRBSet(:)));
            commonProps = {'FrequencyHopping','SecondHopStartPRB','RNTI','NID','NID0'};
            for idx = 1:length(commonProps)
                pucchObj.(commonProps{idx}) = wavePUCCH.(commonProps{idx});
            end
        case 3
            pucchObj = nrPUCCH3Config('SymbolAllocation', symbolAllocation, 'PRBSet', unique(wavePUCCH.PRBSet(:)));
            commonProps = {'FrequencyHopping','SecondHopStartPRB','Modulation','GroupHopping','HoppingID','AdditionalDMRS','NID','RNTI'};
            for idx = 1:length(commonProps)
                pucchObj.(commonProps{idx}) = wavePUCCH.(commonProps{idx});
            end
        otherwise % case 4
            pucchObj = nrPUCCH4Config('SymbolAllocation', symbolAllocation);
            commonProps = {'PRBSet','FrequencyHopping','SecondHopStartPRB','Modulation','GroupHopping','HoppingID','AdditionalDMRS','NID','RNTI','OCCI'};
            for idx = 1:length(commonProps)
                pucchObj.(commonProps{idx}) = wavePUCCH.(commonProps{idx});
            end
    end
    
    % Validate use of sequence hopping for PUCCH
    pucchObj = validatePUCCHSequenceHopping(pucchObj, formatPUCCH, nch);
end

% Validate use of sequence hopping for PUCCH
% The symbols for PUCCH formats 0 and 1 and the DM-RS symbols for PUCCH
% formats 3 and 4 are generated from a low-PAPR sequence type 1. For this
% sequence, sequence hopping (i.e., GroupHopping set to 'disable') can be
% enabled only if the number of subcarriers allocated for PUCCH is greater
% than 72, as mentioned in Section 5.2.2 of TS 38.211.
function pucchObj = validatePUCCHSequenceHopping(pucchObj, formatPUCCH, nch)
    
    % For PUCCH formats 0, 1, and 4, GroupHopping cannot be set to disable
    if any(formatPUCCH==[0 1 4]) && strcmpi(pucchObj.GroupHopping,'disable')
        coder.internal.warning('nr5g:nrWaveformGenerator:InvalidGroupHopping',nch, formatPUCCH);
        pucchObj.GroupHopping = 'neither';
    elseif formatPUCCH == 3
        % Number of subcarriers allocated for PUCCH
        msc = numel(pucchObj.PRBSet(:))*12;
        if strcmpi(pucchObj.GroupHopping,'disable') && msc < 72
            coder.internal.warning('nr5g:nrWaveformGenerator:InvalidGroupHoppingF3',nch);
            pucchObj.GroupHopping = 'neither';
        end
    end
end