%hSSBurstStartSymbols Synchronization Signal Burst OFDM starting symbols
%   STARTSYM = hSSBurstStartSymbols(BURST) returns the first OFDM symbol
%   STARTSYM of every Synchronization Signal block in a burst BURST.
%
%   Note: This is an internal undocumented function and its API and/or
%   functionality may change in subsequent releases.

%   Copyright 2020 The MathWorks, Inc.

%#codegen

function ssbStartSymbols = hSSBurstStartSymbols(burst)
    
    % 'alln' gives the overall set of SS block indices 'n' described in 
    % TS 38.213 Section 4.1, from which a subset is used for each Case A-E
    alln = [0; 1; 2; 3; 5; 6; 7; 8; 10; 11; 12; 13; 15; 16; 17; 18];
    
    L = length(burst.TransmittedBlocks);
    
    cases = nrWavegenSSBurstConfig.BlockPattern_Values;
    m = [14 28 14 28 56];
    i = {[2 8] [4 8 16 20] [2 8] [4 8 16 20] [8 12 16 20 32 36 40 44]};
    nn = [2 1 2 16 8];
    
    caseIdx = find(strcmpi(burst.BlockPattern,cases), 1);
    if ismember(caseIdx, [1 2 3])
        if (L==4)
            nn2 = nn(caseIdx(1));
        else %if (L==8)
            nn2 = nn(caseIdx(1)) * 2;
        end
    else % nrDLCarrierConfig ensures L = 64 for FR2.
        nn2 = nn(caseIdx(1));
    end
    
    n = alln(1:nn2);
    a = i{caseIdx(1)};
    tmp = nr5g.internal.wavegen.addRowAndColumn(m(caseIdx(1))*n, a);
    ssbStartSymbols = tmp(:).';
end