function cfgObj = mapStruct2Obj(cfgS)
% This is an internal, undocumented function that can change anytime. It is
% used to map the legacy struct-based configurations of the waveform
% generator to object-based configurations.

%   Copyright 2020-2021 The MathWorks, Inc.

if isfield(cfgS, 'PDSCH') % nrDLCarrierConfig
  cfgObj = nrDLCarrierConfig;
else
  cfgObj = nrULCarrierConfig;
end

cfgObj.Label = cfgS.Name;

% Top-level parameters:
cfgObj.FrequencyRange   = cfgS.FrequencyRange;
cfgObj.ChannelBandwidth = cfgS.ChannelBandwidth;
cfgObj.NCellID          = cfgS.NCellID;
cfgObj.NumSubframes     = cfgS.NumSubframes;

cfgObj.SCSCarriers      = mapCarriers(cfgS);
cfgObj.BandwidthParts   = mapBWP(cfgS);
if isfield(cfgS, 'PDSCH') % nrDLCarrierConfig
  cfgObj.SSBurst          = mapSSB(cfgS, cfgS.FrequencyRange);
  [cset, ss, pdcch]       = mapControl(cfgS);
  cfgObj.CORESET          = cset;
  cfgObj.SearchSpaces     = ss;
  cfgObj.PDCCH            = pdcch;
  cfgObj.PDSCH            = mapPXSCH(cfgS);
  cfgObj.CSIRS            = mapCSIRS(cfgS);
else % nrULCarrierConfig
  cfgObj.PUSCH            = mapPXSCH(cfgS);
%   cfgObj.SRS              = mapSRS(cfgS);
end

end

function scsCfg = mapCarriers(cfgS)
  
  % Carrier configuration:
  carriers = cfgS.Carriers;
  fMin = inf;
  fMax = -inf;
  for idx = 1:length(carriers)
    scsCfg{idx} = nrSCSCarrierConfig;
    scsCfg{idx}.SubcarrierSpacing = carriers(idx).SubcarrierSpacing; %#ok<*AGROW>
    scsCfg{idx}.NSizeGrid         = carriers(idx).NRB;
    scsCfg{idx}.NStartGrid        = carriers(idx).RBStart;
    
    thisMin = scsCfg{idx}.NStartGrid*12*scsCfg{idx}.SubcarrierSpacing*1e3;
    thisMax = thisMin + scsCfg{idx}.NSizeGrid*12*scsCfg{idx}.SubcarrierSpacing*1e3;
    if thisMin<fMin
      fMin = thisMin;
    end
    if thisMax>fMax
      fMax = thisMax;
    end
  end
  
  waveformCenter = thisMin+(thisMax-thisMin)/2;
  
  % create a carrier for the SS Burst, if a relevant one does not yet exist
  if isfield(cfgS, 'SSBurst') % Downlink
    scs = [carriers.SubcarrierSpacing];
    burstSCS = nr5g.internal.wavegen.blockPattern2SCS(cfgS.SSBurst.BlockPattern);
    if ~any(burstSCS == scs)
      idx = idx + 1;
      scsCfg{idx} = nrSCSCarrierConfig;
      scsCfg{idx}.SubcarrierSpacing = burstSCS; %#ok<*AGROW>
      scsCfg{idx}.NSizeGrid = 20;
      % Place this carrier at the center of the freqencies spanned by the
      % other carriers
      ssbBottom = waveformCenter - (scsCfg{idx}.NSizeGrid/2)*12*burstSCS*1e3;
      start = ssbBottom/(burstSCS*12*1e3);
      if floor(start)~=start
        scsCfg{idx}.NSizeGrid = scsCfg{idx}.NSizeGrid+1;
        ssbBottom = waveformCenter - (scsCfg{idx}.NSizeGrid/2)*12*burstSCS*1e3;
        start = ssbBottom/(burstSCS*12*1e3);
      end
      scsCfg{idx}.NStartGrid = start;
    end
  end
end

function bwp2 = mapBWP(cfgS)
  
  bwp2 = {};

  bwp = cfgS.BWP;
  for idx = 1:length(bwp)
    % Need to work on links between PDSCH and CSIRS
    bwp2{idx} = nrWavegenBWPConfig;
    bwp2{idx}.BandwidthPartID = idx;
    bwp2{idx}.SubcarrierSpacing = bwp(idx).SubcarrierSpacing;
    bwp2{idx}.CyclicPrefix      = bwp(idx).CyclicPrefix;
    bwp2{idx}.NSizeBWP          = bwp(idx).NRB;
    % find carrier for corresponding bwp 
    carrierid = [cfgS.Carriers(:).SubcarrierSpacing] == bwp2{idx}.SubcarrierSpacing;
    bwp2{idx}.NStartBWP         = bwp(idx).RBOffset + cfgS.Carriers(carrierid).RBStart;
  end
end

function ssb2 = mapSSB(cfgS, fr)

  ssb = cfgS.SSBurst;
  scsCfg = cfgS.Carriers;
  
  ssb2 = nrWavegenSSBurstConfig;
  ssb2.Enable             = ssb.Enable;
  ssb2.Power              = ssb.Power;
  ssb2.BlockPattern       = char(ssb.BlockPattern);
  ssb2.TransmittedBlocks  = ssb.SSBTransmitted;
  ssb2.Period             = ssb.SSBPeriodicity;
  ssb2.NCRBSSB            = []; % Carrier center
  ssb2.DataSource         = 'MIB';
  
  if strcmpi(fr, 'FR2')
    ssb2.SubcarrierSpacingCommon = 60;
  % else % FR1
  % ssb2.SubcarrierSpacingCommon = 15; % same as default, already set
  end
end

function [coreset2, ss2, pdcch2] = mapControl(cfgS)
  
  coreset2 = {};
  ss2 = {};
  pdcch2 = {};

  % CORESET (& Search Spaces)
  coreset = cfgS.CORESET;
  numSS = 0;
  for idx = 1:length(coreset)
    coreset2{idx} = nrCORESETConfig;
    coreset2{idx}.CORESETID = idx;
    coreset2{idx}.Label = ['CORESET' num2str(idx)];
    f = coreset(idx).AllocatedPRB/6;
    coreset2{idx}.FrequencyResources = double(ismember(0:min(270/6 - 1, max(f)), f));
    coreset2{idx}.Duration = coreset(idx).Duration;
    if isfield(coreset(idx), 'CCEREGMapping')
      coreset2{idx}.CCEREGMapping   = coreset(idx).CCEREGMapping;
      coreset2{idx}.REGBundleSize   = coreset(idx).REGBundleSize;
      coreset2{idx}.InterleaverSize = coreset(idx).InterleaverSize;
      coreset2{idx}.ShiftIndex      = coreset(idx).ShiftIndex;
    end
    
    % associated search spaces with this CORESET
    for slot = coreset(idx).AllocatedSlots
      for symbol = coreset(idx).AllocatedSymbols
        numSS = numSS + 1;
        ss2{numSS} = nrSearchSpaceConfig;
        ss2{numSS}.SearchSpaceID = numSS - 1;
        ss2{numSS}.Label = ['SearchSpace' num2str(ss2{numSS}.SearchSpaceID)];
        ss2{numSS}.CORESETID = idx;

        ss2{numSS}.SearchSpaceType = 'ue';
        
        ss2{numSS}.StartSymbolWithinSlot =  symbol;
        ss2{numSS}.Duration = coreset.AllocatedPeriod;
        ss2{numSS}.SlotPeriodAndOffset = [coreset.AllocatedPeriod 0];
        
        % avoid validation error occuring if an AL extends beyond the CORESET
        numREGs = numel(coreset.AllocatedPRB)*coreset.Duration;
        crstCCEs = numREGs/6;
        ALs = [1 2 4 8 16];
        ind2del = ALs>crstCCEs;
        ss2{numSS}.NumCandidates(ind2del) = 0;
      end
    end
  end
 
  pdcch = cfgS.PDCCH;
  for idx = 1:length(pdcch)
    pdcch2{idx} = nrWavegenPDCCHConfig;
    pdcch2{idx}.Enable                = pdcch(idx).Enable;
    pdcch2{idx}.Label                 = ['PDCCH' num2str(idx)];
    pdcch2{idx}.Power                 = pdcch(idx).Power;
    pdcch2{idx}.BandwidthPartID       = pdcch(idx).BWP;
    pdcch2{idx}.Coding                = pdcch(idx).EnableCoding;
    pdcch2{idx}.RNTI                  = pdcch(idx).RNTI;
    pdcch2{idx}.DMRSScramblingID      = pdcch(idx).NID;
    pdcch2{idx}.DMRSPower             = pdcch(idx).PowerDMRS;
    pdcch2{idx}.DataBlockSize         = pdcch(idx).DataBlkSize;
    pdcch2{idx}.DataSource            = pdcch(idx).DataSource;
    
    for idx2 = 1:length(ss2)
      if ss2{idx2}.CORESETID == pdcch(idx).CORESET
        if ss2{idx2}.SearchSpaceID == pdcch(idx).AllocatedSearchSpaces(1)
          pdcch2{idx}.SearchSpaceID = ss2{idx2}.SearchSpaceID;
          pdcch2{idx}.SlotAllocation = coreset(pdcch(idx).CORESET).AllocatedSlots;
          pdcch2{idx}.Period = coreset(pdcch(idx).CORESET).AllocatedPeriod;

%           ss2{idx2}.NumCandidates(1) = pdcch(idx).NumCCE;

        end
      end
    end
%     aggLevels = [1 2 4 8 16];
%     diffs = abs(pdcch(idx).NumCCE - aggLevels);
%     [~, minIdx] = min(diffs);
%     pdcch2{idx}.AggregationLevel = aggLevels(minIdx);
%     pdcch2{idx}.AllocatedCandidate = 1;
    
    pdcch2{idx}.AggregationLevel = pdcch(idx).NumCCE;
  end
  
end


function pxsch2 = mapPXSCH(cfgS)

  pxsch2 = {};
  
  % PDSCH
  if isfield(cfgS, 'PDSCH')
    isDownlink = true;
    pxsch = cfgS.PDSCH;
  else
    isDownlink = false;
    pxsch = cfgS.PUSCH;
  end
  
  for idx = 1:length(pxsch)
    if isDownlink
      pxsch2{idx} = nrWavegenPDSCHConfig;
    else
      pxsch2{idx} = nrWavegenPUSCHConfig;
    end
    pxsch2{idx}.Enable               = pxsch(idx).Enable;
    pxsch2{idx}.Power                = pxsch(idx).Power;
    pxsch2{idx}.BandwidthPartID      = pxsch(idx).BWP;
    pxsch2{idx}.Coding               = pxsch(idx).EnableCoding;
    pxsch2{idx}.DataSource           = pxsch(idx).DataSource;
    pxsch2{idx}.TargetCodeRate       = pxsch(idx).TargetCodeRate;
    pxsch2{idx}.Modulation           = pxsch(idx).Modulation;
    pxsch2{idx}.NumLayers            = pxsch(idx).NLayers;
    pxsch2{idx}.RVSequence           = pxsch(idx).RVSequence;
    pxsch2{idx}.SymbolAllocation     = [pxsch(idx).AllocatedSymbols(1) (pxsch(idx).AllocatedSymbols(end)+1-pxsch(idx).AllocatedSymbols(1))];
    pxsch2{idx}.SlotAllocation       = pxsch(idx).AllocatedSlots;
    pxsch2{idx}.Period               = pxsch(idx).AllocatedPeriod;
    pxsch2{idx}.PRBSet               = pxsch(idx).AllocatedPRB;
    pxsch2{idx}.RNTI                 = pxsch(idx).RNTI;
    pxsch2{idx}.NID                  = pxsch(idx).NID;

    if isDownlink
      pxsch2{idx}.XOverhead            = pxsch(idx).Xoh_PDSCH;
      pxsch2{idx}.VRBToPRBInterleaving = pxsch(idx).VRBToPRBInterleaving;
      pxsch2{idx}.VRBBundleSize        = pxsch(idx).VRBBundleSize;
      pxsch2{idx}.MappingType          = pxsch(idx).PDSCHMappingType;
      pxsch2{idx}.TBScaling            = 1;
      
      for idx2 = 1:length(pxsch(idx).RateMatch)
        pxsch2{idx}.ReservedCORESET     = [pxsch2{idx}.ReservedCORESET pxsch(idx).RateMatch(idx2).CORESET];
        pxsch2{idx}.ReservedPRB{idx2} = nrPDSCHReservedConfig;     
        pxsch2{idx}.ReservedPRB{idx2}.PRBSet    = pxsch(idx).RateMatch(idx2).Pattern.AllocatedPRB;
        pxsch2{idx}.ReservedPRB{idx2}.SymbolSet = pxsch(idx).RateMatch(idx2).Pattern.AllocatedSymbols;
        pxsch2{idx}.ReservedPRB{idx2}.Period    = pxsch(idx).RateMatch(idx2).Pattern.AllocatedPeriod;
      end
      
    else
      
      pxsch2{idx}.MappingType          = pxsch(idx).PUSCHMappingType;
      pxsch2{idx}.XOverhead            = pxsch(idx).Xoh_PUSCH;
      pxsch2{idx}.TransformPrecoding   = pxsch(idx).TransformPrecoding;
      pxsch2{idx}.TransmissionScheme   = pxsch(idx).TxScheme;
      
      if strcmp(pxsch(idx).InterSlotFreqHopping, 'enabled')
        pxsch2{idx}.FrequencyHopping = 'interSlot';
      elseif strcmp(pxsch(idx).IntraSlotFreqHopping, 'enabled')
        pxsch2{idx}.FrequencyHopping = 'intraSlot';
      else
        pxsch2{idx}.FrequencyHopping = 'neither';
      end
      pxsch2{idx}.TPMI                 = pxsch(idx).TPMI;
      pxsch2{idx}.NumAntennaPorts      = pxsch(idx).NAntennaPorts;
    end
    
    % Antenna port and DM-RS configuration (TS 38.211 section 7.4.1.1)
    if isDownlink
      dmrs{idx} = nrPDSCHDMRSConfig;
    else
      dmrs{idx} = nrPUSCHDMRSConfig;
    end
    dmrs{idx}.DMRSPortSet             = pxsch(idx).PortSet;
    dmrs{idx}.DMRSTypeAPosition       = pxsch(idx).DMRSTypeAPosition;
    dmrs{idx}.DMRSLength              = pxsch(idx).DMRSLength;
    dmrs{idx}.DMRSAdditionalPosition  = pxsch(idx).DMRSAdditionalPosition;
    dmrs{idx}.DMRSConfigurationType   = pxsch(idx).DMRSConfigurationType;
    dmrs{idx}.NumCDMGroupsWithoutData = pxsch(idx).NumCDMGroupsWithoutData;
    dmrs{idx}.NIDNSCID                = pxsch(idx).NIDNSCID;
    dmrs{idx}.NSCID                   = pxsch(idx).NSCID;
    if ~isDownlink
      dmrs{idx}.NRSID                   = pxsch(idx).NRSID;
    end
    pxsch2{idx}.DMRSPower               = pxsch(idx).PowerDMRS;
%     dmrs{idx}.DMRSReferencePoint      = 'PRB0';
    pxsch2{idx}.DMRS = dmrs{idx};

    if isDownlink
      ptrs{idx} = nrPDSCHPTRSConfig;
    else
      ptrs{idx} = nrPUSCHPTRSConfig;
    end
    pxsch2{idx}.EnablePTRS              = pxsch(idx).EnablePTRS;
    ptrs{idx}.TimeDensity               = pxsch(idx).PTRSTimeDensity;
    ptrs{idx}.FrequencyDensity          = pxsch(idx).PTRSFrequencyDensity;
    ptrs{idx}.REOffset                  = pxsch(idx).PTRSREOffset;
    ptrs{idx}.PTRSPortSet               = pxsch(idx).PTRSPortSet;
    pxsch2{idx}.PTRSPower               = pxsch(idx).PowerPTRS;
    if ~isDownlink
        pxsch2{idx}.NID                 = pxsch(idx).PTRSNID;
    end
    pxsch2{idx}.PTRS = ptrs{idx};
  end
end

function csirs2 = mapCSIRS(cfgS)

  csirs2 = {};

  % CSIRS
  csirs = cfgS.CSIRS;
  for idx = 1:length(csirs)
    csirs2{idx} = nrWavegenCSIRSConfig;
    csirs2{idx}.Enable = csirs(idx).Enable;
    csirs2{idx}.Label = ['CSIRS' num2str(idx)];
    csirs2{idx}.Power = csirs(idx).Power;
    % get the SCS of the BWP
    
    csirs2{idx}.BandwidthPartID = csirs(idx).BWP; 
        
    % This version of the mapper only supports a single CSI-RS per struct/object
    csirs2{idx}.CSIRSType = csirs(idx).CSIRSType;
    csirs2{idx}.RowNumber = csirs(idx).RowNumber;
    csirs2{idx}.Density = csirs(idx).Density;
    csirs2{idx}.SubcarrierLocations = csirs(idx).SubcarrierLocations;
    csirs2{idx}.NumRB = csirs(idx).NumRB;
    csirs2{idx}.RBOffset = csirs(idx).RBOffset;
    csirs2{idx}.SymbolLocations = csirs(idx).SymbolLocations;
    if isempty(csirs(idx).AllocatedPeriod)
      csirs2{idx}.CSIRSPeriod = 'off';
    elseif (iscell(csirs(idx).AllocatedPeriod) && csirs(idx).AllocatedPeriod{1} == 1) ...
        || csirs(idx).AllocatedPeriod == 1
      csirs2{idx}.CSIRSPeriod = 'on';
    else
      csirs2{idx}.CSIRSPeriod = [csirs(idx).AllocatedPeriod csirs(idx).AllocatedSlots];
    end
    csirs2{idx}.NID = csirs(idx).NID;
  end
end
