function [waveform, info] = nrOFDMModulateCallForCodegen(c, cgrid, scs, cp, windowingProp, sr, carrierFreq)
    %nrOFDMModulateCallForCodegen Expand nrOFDMModulate calls for const-inputs needed for codegen
    %
    %   Note: This is an internal undocumented function and its API and/or
    %   functionality may change in subsequent releases.
    
    %   Copyright 2020-2021 The MathWorks, Inc.
    
    %#codegen
        
    % Multiple nrOFDMModulate calls (each with a const Nfft) for codegen:
    nfft = sr/(scs*1e3);
    % maxSR_i is for a carrier_i with nfft_i
    % maxSR_i = SCS_i * 1e3 * nfft_i
    % nfft_i (max) is a power of 2 up to 4096
    %
    % nfft_j of other carrier_j is: maxSR_i/(SCS_j*1e3) =
    % (SCS_i * nfft_i)/(SCS_j)
    % Thus, nfft for non-maxsr carriers can be up to 4*4096, and is still a
    % power of 2

    % Expand nrOFDMModulate calls for const-inputs needed for codegen:
    if coder.target('MATLAB')
        % Calculate windowing samples from windowing Pct (%)
        windowingSamples = windowingPerc2Samples(windowingProp, scs, cp, c.NSizeGrid, sr);
        
        % Call nrOFDMModulate
        [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', windowingSamples, 'SampleRate', sr, 'CarrierFrequency', carrierFreq);
    else
        coder.internal.errorIf(~any(nfft==[128,256,512,1024,2048,4096,8192,16384]), ...
            'nr5g:nrWaveformGenerator:SampleRateCodegen', sr,scs);
        coder.internal.errorIf((carrierFreq~=0),'nr5g:nrWaveformGenerator:CarrierFrequencyCodegen', carrierFreq);
        
        % Calculate windowing samples from windowing Pct (%)
        [windowingSamples, windowingPct] = windowingPerc2Samples(windowingProp, scs, cp, nfft);
        
        % Call nrOFDMModulate
        if isequal(windowingSamples, 0)
            if nfft == 128
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 128, 'CarrierFrequency', 0);
            elseif nfft == 256
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 256, 'CarrierFrequency', 0);
            elseif nfft == 512
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 512, 'CarrierFrequency', 0);
            elseif nfft == 1024
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 1024, 'CarrierFrequency', 0);
            elseif nfft == 2048
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 2048, 'CarrierFrequency', 0);
            elseif nfft == 4096
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 4096, 'CarrierFrequency', 0);
            elseif nfft == 8192
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 8192, 'CarrierFrequency', 0);
            else %if nfft == 16384
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', 0, 'Nfft', 16384, 'CarrierFrequency', 0);
            end
            
        elseif isequal(windowingSamples, [])
            if nfft == 128
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 128, 'CarrierFrequency', 0);
            elseif nfft == 256
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 256, 'CarrierFrequency', 0);
            elseif nfft == 512
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 512, 'CarrierFrequency', 0);
            elseif nfft == 1024
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 1024, 'CarrierFrequency', 0);
            elseif nfft == 2048
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 2048, 'CarrierFrequency', 0);
            elseif nfft == 4096
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 4096, 'CarrierFrequency', 0);
            elseif nfft == 8192
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 8192, 'CarrierFrequency', 0);
            else %if nfft == 16384
                [waveform, info] = nrOFDMModulate(c, cgrid, 'Windowing', [], 'Nfft', 16384, 'CarrierFrequency', 0);
            end
        else
            coder.internal.error('nr5g:nrWaveformGenerator:WindowingCodegen', windowingPct(1));
        end
    end
end

% Convert WindowingPercent to number of samples
function [nsamp, windowingPct] = windowingPerc2Samples(windowingProp, scs, cp, varargin)
    % This function accepts 1 or 2 optional inputs. If there is only one
    % optional input, this is NFFT. Otherwise, the two inputs are NRB and
    % SampleRate, respectively.
    if numel(windowingProp) <= 1
        windowingPct = windowingProp;
    else
        % nrDLCarrierConfig offers 6 elements in this case
        % [15   30    60normal    60extended    120     240]
        % nrULCarrierConfig offers 5 elements in this case
        % [15   30    60normal    60extended    120]
        muID = 1 + log2(scs/15) + 1*(scs>=120) + ...
            1*(scs==60 && strcmpi(cp, 'extended'));
        windowingPct = windowingProp(muID);
    end
    if nargin > 4
        nrb = varargin{1};
        sr = varargin{2};
        r = nrOFDMInfo(nrb, scs, 'SampleRate', sr);
        nfft = r.Nfft;
    else
        nfft = varargin{1};
    end
    nsamp = floor(windowingPct*nfft/100);
end
