classdef PTRSConfigBase < nr5g.internal.ConfigBase
    %PTRSConfigBase Base object for PT-RS configuration object
    %
    %   Note: This is an internal undocumented class and its API and/or
    %   functionality may change in subsequent releases.

    % Copyright 2019 The MathWorks, Inc.

    %#codegen

    properties
        % TS 38.211 sections 6.4.1.2 and 7.4.1.2

        %TimeDensity Time density (L_PT-RS)
        %   Specify the time density of PT-RS as a scalar positive integer.
        %   The value must be one of {1, 2, 4}. The default value is 1.
        TimeDensity = 1;

        %FrequencyDensity Frequency density (K_PT-RS)
        %   Specify the frequency density of PT-RS as a scalar positive
        %   integer. The value must be one of {2, 4}. The default value is 2.
        FrequencyDensity = 2;

        %REOffset Resource element offset
        %   Specify the subcarrier offset as a character array or a scalar
        %   string. The value must be one of {'00', '01', '10', '11'},
        %   provided by higher-layer parameter resourceElementOffset. The
        %   default value is '00'.
        REOffset = '00';
    end

    properties(Constant, Hidden)
        REOffset_Values = {'00','01','10','11'};
    end

    methods
        function obj = PTRSConfigBase(varargin)
            %PTRSConfigBase Create a PTRSConfigBase object
            %   Set the property values from any name-value pairs input to
            %   the object

            % Call the base class constructor method with all the
            % name-value pairs input
            obj@nr5g.internal.ConfigBase(varargin{:});
        end

        function obj = set.TimeDensity(obj,val)
            prop = 'TimeDensity';
            validateattributes(val, {'numeric'}, ...
                {'real','scalar'}, ...
                [class(obj) '.' prop], prop);
            coder.internal.errorIf(~any(val==[1 2 4]), ...
                'nr5g:PTRSConfigBase:InvalidTimeDensity',sprintf('%g',double(val)));
            obj.(prop) = val;
        end

        function obj = set.FrequencyDensity(obj,val)
            prop = 'FrequencyDensity';
            validateattributes(val, {'numeric'}, ...
                {'real','scalar'}, ...
                [class(obj) '.' prop], prop);
            coder.internal.errorIf(~any(val==[2 4]), ...
                'nr5g:PTRSConfigBase:InvalidFrequencyDensity',sprintf('%g',double(val)));
            obj.(prop) = val;
        end

        function obj = set.REOffset(obj,val)
            prop = 'REOffset';
            val = validatestring(val, obj.REOffset_Values,...
                [class(obj) '.' prop], prop);
            obj.(prop) = val;
        end
    end
end