classdef nrSRSConfigBase < nr5g.internal.ConfigBase
    %nrSRSConfigBase Class offering properties common between nrSRSConfig and
    %nrWavegenSRSConfig
    %
    %   Note: This is an internal undocumented class and its API and/or
    %   functionality may change in subsequent releases.

    %   Copyright 2020 The MathWorks, Inc.

    %#codegen

    % Public, tunable properties
    properties
        %NumSRSPorts Number of SRS antenna ports
        %   Specify the number of SRS antenna ports. The value must be one
        %   of {1, 2, 4}. The default value is 1.
        NumSRSPorts = 1;
        
        %NumSRSSymbols Number of SRS symbols
        %   Specify the number of consecutive OFDM symbols in a slot. The
        %   value must be one of {1, 2, 4}. When the SRSPositioning
        %   property is set to true, NumSRSSymbols must be one of {1, 2, 4,
        %   8, 12} and the SubcarrierOffsetTable property of <a href="matlab:
        %   help('nrSRSConfig.SubcarrierOffsetTable')">nrSRSConfig</a>
        %   specifies valid configurations of the NumSRSSymbols and KTC
        %   properties. The default value is 1.
        NumSRSSymbols = 1;
        
        %SymbolStart 0-based index of the first SRS symbol in a slot (L0)
        %   Specify the first OFDM symbol in a slot where the SRS is
        %   transmitted. The SRS must be allocated within the slot
        %   boundaries. The default value is 13.
        SymbolStart = 13;
        
        %KTC Transmission comb number in subcarriers
        %   Specify the frequency density of the SRS in subcarriers. The
        %   SRS is allocated every KTC subcarriers. The value of KTC must
        %   be one of {2, 4}. When the SRSPositioning property is set to
        %   true, KTC must be one of {2, 4, 8} and the SubcarrierOffsetTable
        %   property of <a href="matlab:help('nrSRSConfig.SubcarrierOffsetTable')"
        %   >nrSRSConfig</a> specifies valid configurations of the
        %   NumSRSSymbols and KTC properties. The default value is 2.
        KTC = 2;
        
        %KBarTC Transmission comb offset in subcarriers
        %   Specify an offset of the transmission comb in subcarriers. The
        %   value must be an integer in the range 0...KTC-1. The default
        %   value is 0.
        KBarTC = 0;
        
        %CyclicShift Cyclic shift number offset (NCS)
        %   The cyclic shift number offset determines the origin of the
        %   cyclic shift applied to the SRS for all antenna ports. The
        %   value must be an integer in the range 0...NCSmax-1, where
        %   NCSmax = 6 for KTC = 8, NCSmax = 12 for KTC = 4, NCSmax = 8 for
        %   KTC = 2. Consecutive cyclic shift numbers (modulo NCSmax) are
        %   used for multiport SRS transmissions. The default value is 0.
        CyclicShift = 0;
        
        %FrequencyStart Frequency-domain starting position
        %   Specify the index of the first PRB allocated to the SRS in the
        %   frequency domain relative to the carrier resource grid when the
        %   property NRRC = 0. The value must be an integer in the range
        %   0...271. The default value is 0.
        FrequencyStart = 0;
        
        %NRRC Frequency domain additional position in 4-PRB blocks
        %   Specify an additional circular frequency offset to
        %   FrequencyStart in blocks of 4 RBs. The value must be an integer
        %   in the range 0...67. The resulting location of the SRS in the
        %   frequency domain depends on FrequencyStart and the
        %   configuration parameters specified in TS 38.211 Table
        %   6.4.1.4.3-1. The default value is 0.
        NRRC = 0;
        
        %CSRS Row index of the bandwidth configuration table
        %   Specify the bandwidth configuration index to control the
        %   bandwidth allocated to the SRS and the frequency hopping
        %   pattern according to TS 38.211 Table 6.4.1.4.3-1. Larger values
        %   of CSRS result in larger SRS bandwidths. The value must be an
        %   integer in the range 0...63. The default value is 0, which
        %   results in 4-PRB bandwidth.
        CSRS = 0;
        
        %BSRS Column index of the bandwidth configuration table
        %   Specify the bandwidth configuration index to control the
        %   bandwidth allocated to the SRS and the frequency hopping
        %   pattern according to TS 38.211 Table 6.4.1.4.3-1. Larger values
        %   of BSRS result in smaller SRS bandwidths per OFDM symbol. The
        %   value must be an integer in the range 0...3. The default
        %   value is 0.
        BSRS = 0;
        
        %BHop Frequency hopping index
        %   Specify the frequency hopping index to control the frequency
        %   hopping bandwidth and pattern. The value must be an integer in
        %   the range 0...3. Setting BHop >= BSRS disables frequency
        %   hopping. Larger values of BHop (< BSRS) result in smaller
        %   hopping bandwidths. The default value is 0.
        BHop = 0;
        
        %Repetition Repetition factor in OFDM symbols
        %   Specify the number of consecutive OFDM symbols in a slot for
        %   which the SRS is located in the same frequency resources when
        %   frequency hopping is active. The value must be one of
        %   {1, 2, 4, 8, 12}. Repetition must be lower than NumSRSSymbols when
        %   frequency hopping is active and it is ignored when frequency
        %   hopping is not active. The default value is 1 (no repetition).
        Repetition = 1;
        
        %GroupSeqHopping Group or sequence numbers hopping
        %   Specify the type of SRS symbol hopping. The value must be one
        %   of ('neither', 'groupHopping', 'sequenceHopping'). When group or
        %   sequence hopping are enabled, a pseudorandom binary sequence
        %   (PRBS) is used to calculate the sequence and group numbers per
        %   OFDM symbol of the SRS transmission. The default value is 'neither'.
        GroupSeqHopping = nr5g.internal.nrSRSConfigBase.getDefault('GroupSeqHopping');

        %NSRSID Scrambling identity
        %   Specify the scrambling identity of the SRS. The value must be
        %   an integer in the range 0...65535. NSRSID determines the
        %   group number when the GroupSeqHopping property is set to
        %   'neither'. Otherwise, it is employed to initialize the
        %   pseudorandom binary sequence (PRBS) for group or sequence
        %   hopping configurations. The default value is 0.
        NSRSID = 0;
        
        %SRSPositioning Enable SRS for user positioning 
        % Specify the use of the SRS for positioning. A value of true
        % corresponds to the higher-layer parameter 'SRS-PosResource-r16'
        % and false corresponds to 'SRS-Resource'. The default value is
        % false.
        SRSPositioning = false;
    end
    
    % Constant, hidden properties
    properties (Constant,Hidden)

        NumSRSPorts_Options      = [1 2 4];
        NumSRSSymbols_Options    = [1 2 4 8 12];
        SymbolStart_Options      = 0:13;
        KTC_Options              = [2,4,8];
        KBarTC_Options           = 0:7;
        CyclicShift_Options      = 0:11;
        FrequencyStart_Options   = 0:271;
        NRRC_Options             = 0:67;
        CSRS_Options             = 0:63;
        BSRS_Options             = 0:3;
        BHop_Options             = 0:3;
        Repetition_Options       = [1 2 4 8 12];
        GroupSeqHopping_Values   = {'neither','groupHopping','sequenceHopping'};
    end
    
    methods
        
        % Constructor
        function obj = nrSRSConfigBase(varargin)
            % Support name-value pair arguments when constructing object
            obj@nr5g.internal.ConfigBase(...
                'GroupSeqHopping',nr5g.internal.nrSRSConfigBase.getDefault('GroupSeqHopping'),...
                varargin{:}); % Set variable-size properties for codegen compatibility
        end
        
        % Self-validate and set properties
        function obj = set.NumSRSPorts(obj,val) 
            propName = 'NumSRSPorts';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
       
        function obj = set.NumSRSSymbols(obj,val) 
            propName = 'NumSRSSymbols';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.SymbolStart(obj,val) 
            propName = 'SymbolStart';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.KTC(obj,val) 
            propName = 'KTC';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.KBarTC(obj,val) 
            propName = 'KBarTC';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
                
        function obj = set.CyclicShift(obj,val) 
            propName = 'CyclicShift';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.FrequencyStart(obj,val) 
            propName = 'FrequencyStart';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.NRRC(obj,val) 
            propName = 'NRRC';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.CSRS(obj,val) 
            propName = 'CSRS';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.BSRS(obj,val) 
            propName = 'BSRS';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end 
        
        function obj = set.BHop(obj,val) 
            propName = 'BHop';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
  
        function obj = set.Repetition(obj,val) 
            propName = 'Repetition';
            obj.validatePropValues(propName,val);
            obj.(propName) = val;
        end
        
        function obj = set.NSRSID(obj,val)
            prop = 'NSRSID';
            validateattributes(val,{'numeric'},...
                {'scalar','integer','nonnegative','<=',65535},...
                [class(obj) '.' prop],prop);
            obj.(prop) = val;
        end
        
        function obj = set.GroupSeqHopping(obj,val)
            propName = 'GroupSeqHopping';
            validateattributes(val,{'char','string'},...
                {'nonempty'},[class(obj) '.' propName],propName);
            val = validatestring(val,obj.GroupSeqHopping_Values,[class(obj) '.' propName],propName);
            obj.(propName) = ''; % For codegen compatibility
            obj.(propName) = val;
        end
        
        function obj = set.SRSPositioning(obj,val)
            prop = 'SRSPositioning';
            validateattributes(val, {'logical', 'numeric'}, {'scalar','real','nonnan'}, ...
                [class(obj) '.' prop], prop);
            obj.(prop) = logical(val);
        end
    end
    
    methods (Access = public)
        
        % Method to check cross dependencies
        function validateConfig(obj)
            
            % Validate SRS configuration
            if obj.SRSPositioning
                offt = nr5g.internal.SRSOffsetK;
                nSym = obj.NumSRSSymbols_Options;
                symIdx = [0 nSym]==obj.NumSRSSymbols;
                ktcIdx = [2 4 8]==obj.KTC;
                if any(isnan(offt{ktcIdx,symIdx}(1)))
                    coder.internal.error('nr5g:nrSRS:InconsistentPositioningConfiguration',obj.NumSRSSymbols,obj.KTC);
                end
            else % SRSPositioning = false
                props = {'NumSRSSymbols','KTC','Repetition'};
                valopts = {[1 2 4],[2,4],[1 2 4]};
                for p = 1:length(props)
                    propName = props{p};
                    val = obj.(propName);
                    opts = valopts{p};
                    if ~any(val == opts)
                        propValuesString = sprintf('%d, ',opts);
                        coder.internal.error('nr5g:nrSRS:InvalidPropertyValueNonPositioning',propName, val, propValuesString(1:end-2));
                    end
                end
                
            end
            
            if obj.KBarTC >= obj.KTC
                coder.internal.error('nr5g:nrSRS:InconsistentComb',obj.KBarTC,obj.KTC);
            elseif obj.BHop < obj.BSRS && obj.Repetition > obj.NumSRSSymbols
                coder.internal.error('nr5g:nrSRS:InconsistentRepetition',obj.Repetition,obj.NumSRSSymbols);
            end
            
            % Validate cyclic shift number offset CyclicShift
            maxcs = [8 12 6];
            nCSmax = maxcs(log2(double(obj.KTC)));
            if obj.CyclicShift >= nCSmax
                coder.internal.error('nr5g:nrSRS:InconsistentCyclicShift',obj.CyclicShift,nCSmax-1,obj.KTC);
            end
        end
        
    end
    
    methods ( Access = private )
        % Common method used to validate setters
        function obj = validatePropValues(obj,propName,val)    
            % Check types first
            validateattributes(val,{'numeric'},{'scalar','integer'},[class(obj) '.' propName],propName);
            
            opts = obj.([propName '_Options']);
            if ~any(val == opts)
                if ~all(diff(opts)==1) % Not a range
                    propValuesString = sprintf('%d, ',opts);
                    coder.internal.error('nr5g:nrSRS:InvalidPropertyValue',propName, val, propValuesString(1:end-2));
                else
                    coder.internal.error('nr5g:nrSRS:OutOfRangePropertyValue',propName, val, num2str(opts(1)), num2str(opts(end)));
                end
            end
        end
    end
    
    methods (Static, Access = private)
        % Default values of variable-size char properties. This allows to
        % localize the defaults required for codegen compatibility
        function out = getDefault(propName)
            switch propName
                case 'GroupSeqHopping'
                    out = 'neither';
            end
        end
    end
end