classdef nr5G_FRC_DL_Dialog < wirelessWaveformGenerator.nr5G_FRC_Dialog
%

%   Copyright 2019-2021 The MathWorks, Inc.
  
  properties (Dependent)
    OCNG % Checkbox to enable or disable OCNG
  end

  properties (Hidden, Dependent)
    Modulation
    TargetCodingRate
  end
  
  properties (Hidden)
    TitleString = getString(message('nr5g:waveformGeneratorApp:nrDLFRCTitle'))
        
    infoClass = 'wirelessWaveformGenerator.nr5G_DL_InfoDialog'
    MCS1 = {'QPSK, R=1/3', '64QAM, R=3/4', '256QAM, R=4/5'}
    MCS2 = {'QPSK, R=1/3', '64QAM, R=1/2'}
    OCNGType = 'checkbox'
    OCNGGUI
    OCNGLabel
  end
   
  methods
    function obj = nr5G_FRC_DL_Dialog(parent)
      obj@wirelessWaveformGenerator.nr5G_FRC_Dialog(parent); % call base constructor
            
      obj.NLayersGUI.Callback   = @(a,b) layersChanged(obj, []);  % Dialog specific callback
      obj.OCNGGUI.Callback    = @(a,b) OCNGChanged(obj);

      % Enable toolbar in grid fig if using Java version
      useJava = ~obj.Parent.WaveformGenerator.useAppContainer;
      if useJava
        % Enable interactive toolbars for grid fig:
        figName = 'Resource Grid (BWP#1)';
        ax = obj.getVisualAxes(figName);
        ax.Toolbar.Visible = 'on'; % interactive toolbar
      end
    end    
    
    function adjustSpec(obj)
      obj.MCSDropDown = obj.MCS1;
      
      % For MATLAB script generation
      obj.configGenFcn  = @nrDLCarrierConfig;
      obj.configGenVar  = 'cfgDLFRC';
    end
    
    function props = displayOrder(~)
      props = {'FrequencyRange'; 'MCS'; 'SubcarrierSpacing'; 'ChannelBandwidth';...
        'DuplexMode'; 'NumSubframes'; 'NLayers'; 'NCellID'; 'RNTI'; 'OCNG';...
        'WindowingSource'; 'WindowingPercent'; 'SampleRateSource'; ...
        'SampleRate'; 'PhaseCompensation'; 'CarrierFrequency'};
    end
    
    function [blockName, maskTitleName, waveNameText] = getMaskTextWaveName(obj)
        blockName = ['5G NR ' obj.Parent.WaveformGenerator.pCurrentWaveformType];
        maskTitleName = ['5G NR ' obj.Parent.WaveformGenerator.pCurrentWaveformType ' Waveform Generator'];
        waveNameText = 'a 5G NR downlink FRC';
    end
    
    function restoreDefaults(obj)
      obj.FrequencyRange    = 'FR1';
      obj.MCS               = 'QPSK, R=1/3';
      obj.DuplexMode = 'FDD';
      obj.SubcarrierSpacing = 15;
      obj.ChannelBandwidth  = 5;
      obj.NumSubframes      = 10;
      obj.NCellID           = 1;
      obj.RNTI              = 1;
      obj.OCNG              = false;  % Checkbox
      
      restoreMods(obj); 
    end
    
    function str = getIconDrawingCommand(obj)
        str = ['disp([' obj.configGenVar '.Label newline ...' newline ...
                '''SCS: '' num2str(' obj.configGenVar '.BandwidthParts{1}.SubcarrierSpacing) ''kHz'' newline ...' newline ...
                '''Bandwidth: '' num2str(' obj.configGenVar '.ChannelBandwidth) ''MHz'' newline ...' newline ...
                '''Subframes: '' num2str(' obj.configGenVar '.NumSubframes) ]);'];
    end
    
    function updateInfo(obj)
      try
        try
          cfg = getConfiguration(obj);
        catch
          % Initialization; possibly inconsistent state
          return;
        end
        if ~obj.Parent.DialogsMap.isKey(obj.infoClass)
          % dialog initialization
          return;
        end
        ch = cfg.PDSCH{1};
        
        infoDialog = obj.Parent.DialogsMap(obj.infoClass);
        infoDialog.SubcarrierSpacing      = cfg.SCSCarriers{1}.SubcarrierSpacing;
        infoDialog.AllocatedRBs           = length(ch.PRBSet);
        infoDialog.Modulation             = ch.Modulation;
        mcs = obj.MCS;
        idx = strfind(mcs, '=');
        rate = mcs(idx(1)+1:end);
        infoDialog.TargetCodeRateGUI.String = rate;
        
        infoDialog.DMRSConfigurationType  = ch.DMRS.DMRSConfigurationType;
        infoDialog.DMRSAdditionalPosition = ch.DMRS.DMRSAdditionalPosition;
        infoDialog.DMRSTypeAPosition      = ch.DMRS.DMRSTypeAPosition;
        
        infoDialog.AllocatedSymbolsGUI.String = sprintf('[%d %d]',ch.SymbolAllocation);
        infoDialog.Xoh_PDSCH              = ch.XOverhead;
        infoDialog.PDSCHMappingType       = ch.MappingType;
        
        % Calculate Payload (bits) / Transport Block Size (TBS)
        % Use the same methodology used by waveform generators
        carrier = nrCarrierConfig('NCellID', cfg.NCellID, ...
                                  'SubcarrierSpacing', cfg.BandwidthParts{1}.SubcarrierSpacing, ...
                                  'CyclicPrefix', cfg.BandwidthParts{1}.CyclicPrefix, ...
                                  'NSizeGrid', cfg.BandwidthParts{1}.NSizeBWP, ...
                                  'NStartGrid', cfg.BandwidthParts{1}.NStartBWP);
        ptrs = nrPDSCHPTRSConfig('TimeDensity', ch.PTRS.TimeDensity, ...
                                  'FrequencyDensity', ch.PTRS.FrequencyDensity, ...
                                  'REOffset', ch.PTRS.REOffset, ...
                                  'PTRSPortSet', ch.PTRS.PTRSPortSet);
        dmrs = nrPDSCHDMRSConfig('DMRSConfigurationType', ch.DMRS.DMRSConfigurationType, ...
                                  'DMRSTypeAPosition', ch.DMRS.DMRSTypeAPosition, ...
                                  'DMRSAdditionalPosition', ch.DMRS.DMRSAdditionalPosition, ...
                                  'DMRSLength', ch.DMRS.DMRSLength, ...
                                  'NIDNSCID', ch.DMRS.NIDNSCID, ...
                                  'NSCID', ch.DMRS.NSCID, ...
                                  'NumCDMGroupsWithoutData', ch.DMRS.NumCDMGroupsWithoutData);
        pdsch = nrPDSCHConfig('NSizeBWP', cfg.BandwidthParts{1}.NSizeBWP, ...
                              'NStartBWP', cfg.BandwidthParts{1}.NStartBWP, ...
                              'Modulation', ch.Modulation, ...
                              'NumLayers', ch.NumLayers, ...
                              'MappingType', ch.MappingType, ...
                              'SymbolAllocation', ch.SymbolAllocation, ...
                              'PRBSet', ch.PRBSet, ...
                              'NID', ch.NID, ...
                              'RNTI', ch.RNTI, ...
                              'EnablePTRS', ch.EnablePTRS, ...
                              'PTRS', ptrs, ...
                              'DMRS', dmrs);
                              
        [~, modinfo] = nrPDSCHIndices(carrier, pdsch);
        infoDialog.PayloadSize  = nrTBS(ch.Modulation, ch.NumLayers, length(ch.PRBSet), ...
            modinfo.NREPerPRB, ch.TargetCodeRate, ch.XOverhead);
        
      catch exc
        % nrFRCDL may error
        obj.errorFromException(exc);
      end
    end
    
    function cfg = getConfiguration(obj)
        
      refObj = wirelessWaveformGenerator.internal.hNRReferenceWaveformGenerator(obj.FRC, ...
          obj.ChannelBandwidth,obj.SubcarrierSpacing,obj.DuplexMode,double(obj.NCellID),[],[],obj.OCNG);
      cfg = refObj.Config;
      
      % Tweak the preset parameters to reflect the additional dialog state
      cfg.NumSubframes              = double(obj.NumSubframes);
      cfg.PDSCH{1}.RNTI             = double(obj.RNTI);     
      cfg.PDSCH{1}.NumLayers        = obj.NLayers;
      
      % In the OCNG PDSCHs, set a different RNTI from the one used by 
      % the reference PDSCH and set the same number of layers
      for i=2:length(cfg.PDSCH)
        cfg.PDSCH{i}.RNTI = mod(cfg.PDSCH{1}.RNTI + 1,65519) + 1;
        cfg.PDSCH{i}.NumLayers = cfg.PDSCH{1}.NumLayers;
      end

      % Set the PDSCH data source 
      cfg = getConfigurationDataSource(obj,'PDSCH',cfg);
      % Set the modulation related parameters
      cfg = getConfigurationMods(obj,cfg);
    end
  
    function frChanged(obj, ~)
      frChanged@wirelessWaveformGenerator.nr5G_Dialog(obj);
      
      obj.MCSGUI.Value = 1;
      if strcmp(obj.FrequencyRange, 'FR1')
        obj.MCSGUI.String = obj.MCS1;
      else
        obj.MCSGUI.String = obj.MCS2;
      end
      
      updateInfo(obj);
      
    end
    
    function mcsChanged(obj, ~)
      
      updateInfo(obj);

    end    
    
    function layersChanged(obj, ~)
      updateInfo(obj);
    end

    function OCNGChanged(obj)
      updateInfo(obj);

      updateGrid(obj);
    end

    function scsChanged(obj, ~)
      scsChanged@wirelessWaveformGenerator.nr5G_Dialog(obj);
      updateGrid(obj);
      updateChannelView(obj);
    end
    
    function mod = get.Modulation(obj)
      mcs = obj.MCS;
      idx = strfind(mcs, ',');
      mod = mcs(1:idx(1)-1);
    end
    
    function mod = get.TargetCodingRate(obj)
      mcs = obj.MCS;
      idx = strfind(mcs, '=');
      rate = mcs(idx(1)+1:end);
      % do conversions that are necessary to match the Payload Size from the standard's tables
      if strcmp(rate, '1/3')
        rate = '308/1024'; % only used for QPSK
      elseif strcmp(rate, '1/2')
        rate = '517/1024'; % only used for 64-QAM
      elseif strcmp(rate, '3/4')
        rate = '772/1024'; % only used for 64-QAM
      elseif strcmp(rate, '4/5')
        rate = '822/1024'; % only used for 256-QAM
      end
      mod = eval(rate);
    end  
    
    function frc = getFRC(obj)
      frc = ['DL-FRC-' obj.FrequencyRange '-' obj.Modulation];
    end

    function v = get.OCNG(obj) 
      v = logical(obj.OCNGGUI.Value);
    end

    function set.OCNG(obj, val) 
      obj.OCNGGUI.Value = val;
    end

  end

end