classdef nr5G_FRC_Dialog < wirelessWaveformGenerator.nr5G_Dialog
%

%   Copyright 2019-2021 The MathWorks, Inc.
  
  properties (Dependent)
    FRC                 % FRC label, e.g., 'G-FR1-A1-1'
    MCS                 % MCS description, e.g., 'QPSK, R=1/3'
  end
  
  properties (Abstract, Hidden)
    infoClass
  end
  
  properties (Hidden)
    FRCType = 'popupmenu'
    FRCDropDown = ''
    FRCGUI
    FRCLabel
    
    MCSType = 'popupmenu'
    MCSDropDown = {'QPSK, R=1/3', '16QAM, R=2/3', 'QPSK, R=193/1024', '16QAM, R=658/1024', '64QAM, R=567/1024'}
    MCSGUI
    MCSLabel
  end  
  
  methods
    function obj = nr5G_FRC_Dialog(parent)
      obj@wirelessWaveformGenerator.nr5G_Dialog(parent); % call base constructor
      
      if ~isKey(obj.Parent.DialogsMap, obj.infoClass)
        obj.Parent.DialogsMap(obj.infoClass) = eval([obj.infoClass '(obj.Parent)']);
      end
      
      obj.MCSGUI.Callback       = @(a,b) mcsChanged(obj, []);
      obj.FRCGUI.Callback       = @(a,b) frcChanged(obj, []);
      
      % Sync GUI controls with dialog state
      windowingChangedGUI(obj, []);
      srChangedGUI(obj, []);
      phaseCompChangedGUI(obj, []);     
      
      updateInfo(obj);
    end
    
    function config = getConfigurationForSave(obj)
      config.waveform   = getConfigurationForSave@wirelessWaveformGenerator.Dialog(obj);
      config.generation = getConfigurationForSave(obj.Parent.GenerationDialog); 
      config.filtering  = getConfigurationForSave(obj.Parent.FilteringDialog);
    end
    
    function applyConfiguration(obj, cfg)
      % This jumps down to the direct property mapping in the base wireless 'Dialog' class
      applyConfiguration@wirelessWaveformGenerator.nr5G_Dialog(obj, cfg);
      
      updateInfo(obj);
    end
    
    function waveform = generateWaveform(obj)
      waveconfig = getConfiguration(obj);
      [waveform, obj.gridSet] = nrWaveformGenerator(waveconfig);
      updateInfo(obj);
    end

    function frc = get.FRC(obj) 
      frc = obj.getFRC(); % allow override by DL FRC class
    end
    function frc = getFRC(obj)
      frc = obj.FRCGUI.String{obj.FRCGUI.Value};
      % trim everything after 1st space, e.g., (SCS, NumRBs)
      idx = strfind(frc, ' ');
      frc = frc(1:idx(1)-1);
    end
    function set.FRC(obj, val) 
      % add space in the end, as string 'A3-1' is contained within 'A3-11' (false positive)
      obj.FRCGUI.Value = find(contains(obj.FRCGUI.String, [val ' ']));
    end
    
    function mcs = get.MCS(obj) 
      mcs = obj.MCSGUI.String{obj.MCSGUI.Value};
    end
    function set.MCS(obj, val) 
      obj.MCSGUI.Value = find(contains(obj.MCSGUI.String, val)); 
      
      mcsChanged(obj);
    end
    
    function c = getSourceClass(~)
      c = 'wirelessWaveformGenerator.BitSourceDialog';
    end
    
    function cellDialogs = getDialogsPerColumn(obj)
      cellDialogs{1} = {obj obj.Parent.GenerationDialog obj.Parent.FilteringDialog};
      cellDialogs{2} = {obj.Parent.DialogsMap(obj.infoClass)};
    end
  end

end