classdef nr5G_PDSCHDMRS_Dialog < wirelessWaveformGenerator.nr5G_PXSCHDMRS_Dialog
% Interface to properties that are unique for PDSCH DMRS

%   Copyright 2020 The MathWorks, Inc.
  
  properties (Dependent)
    DMRSReferencePoint
  end  
  
  properties (Hidden)
    TitleString = 'PDSCH 1 DM-RS'

    DMRSReferencePointType = 'popupmenu'
    DMRSReferencePointDropDown = {'CRB0', 'PRB0'}
    DMRSReferencePointLabel
    DMRSReferencePointGUI
  end
  
  methods
    function obj = nr5G_PDSCHDMRS_Dialog(parent, fig)
      obj@wirelessWaveformGenerator.nr5G_PXSCHDMRS_Dialog(parent, fig); % call base constructor
    end
    
    function adjustDialog(obj)
      % Make sure all tags are unique. Otherwise there is a conflict with SSB
      obj.DMRSTypeAPositionGUI.Tag = 'PDSCHDMRSTypeAPosition';
    end
    
    function props = displayOrder(~)
      props = {'Power'; 'DMRSConfigurationType'; 'DMRSReferencePoint'; 'DMRSTypeAPosition';
              'DMRSAdditionalPosition'; 'DMRSLength'; 'CustomSymbolSet'; 
              'DMRSPortSet'; 'NIDNSCID'; 'NSCID'; 'NumCDMGroupsWithoutData'};
    end
    
    function restoreDefaults(obj)
      % Get the same defaults with programmatic objects
      c = nrWavegenPDSCHConfig;
      obj.Power                   = c.DMRSPower;
      
      c = nrPDSCHDMRSConfig;
      obj.DMRSConfigurationType   = c.DMRSConfigurationType;
      obj.DMRSReferencePoint      = c.DMRSReferencePoint;
      obj.DMRSTypeAPosition       = c.DMRSTypeAPosition;
      obj.DMRSAdditionalPosition  = c.DMRSAdditionalPosition;
      obj.DMRSLength              = c.DMRSLength;
      obj.CustomSymbolSet         = c.CustomSymbolSet;
      obj.DMRSPortSet             = c.DMRSPortSet;
      obj.NIDNSCID                = c.NIDNSCID;
      obj.NSCID                   = c.NSCID;
      obj.NumCDMGroupsWithoutData = c.NumCDMGroupsWithoutData;
    end
    
    % Getter/setter
    function fr = get.DMRSReferencePoint(obj) 
      fr = obj.DMRSReferencePointGUI.String{obj.DMRSReferencePointGUI.Value};
    end
    function set.DMRSReferencePoint(obj, val) 
      obj.DMRSReferencePointGUI.Value = find(strcmp(obj.DMRSReferencePointGUI.String, val)); 
    end
  end
end
