classdef nr5G_PUCCHUCI_Dialog < wirelessWaveformGenerator.Dialog
    % Interface to all UCI properties

    %   Copyright 2021 The MathWorks, Inc.

    properties (Dependent)
        NumUCIBits_f01 % Formats 0, 1
        NumUCIBits_f2 % Format 2
        NumUCIBits_f34 % Formats 3, 4
        DataSourceUCI_f012 % Formats 0, 1, 2
        CustomDataSourceUCI_f012 % Formats 0, 1, 2
        DataSourceUCI_f34 % Formats 3, 4
        CustomDataSourceUCI_f34 % Formats 3, 4
        DataSourceSR
        CustomDataSourceSR
        NumUCI2Bits
        DataSourceUCI2
        CustomDataSourceUCI2
        TargetCodeRate
    end

    properties (Hidden)
        TitleString = 'PUCCH 1 UCI'
        configFcn = @struct
        format = '0';

        NumUCIBits_f01Type = 'popupmenu'
        NumUCIBits_f01DropDown = {'0', '1', '2'}
        NumUCIBits_f01Label
        NumUCIBits_f01GUI

        NumUCIBits_f2Type = 'edit'
        NumUCIBits_f2Label
        NumUCIBits_f2GUI

        NumUCIBits_f34Type = 'edit'
        NumUCIBits_f34Label
        NumUCIBits_f34GUI

        DataSourceUCI_f012Type = 'popupmenu'
        DataSourceUCI_f012DropDown = {'PN9-ITU','PN9','PN11', 'PN15', 'PN23', 'User-defined'}
        DataSourceUCI_f012Label
        DataSourceUCI_f012GUI

        CustomDataSourceUCI_f012Type = 'edit'
        CustomDataSourceUCI_f012Label
        CustomDataSourceUCI_f012GUI

        DataSourceUCI_f34Type = 'popupmenu'
        DataSourceUCI_f34DropDown = {'PN9-ITU','PN9','PN11', 'PN15', 'PN23', 'User-defined'}
        DataSourceUCI_f34Label
        DataSourceUCI_f34GUI

        CustomDataSourceUCI_f34Type = 'edit'
        CustomDataSourceUCI_f34Label
        CustomDataSourceUCI_f34GUI

        NumUCI2BitsType = 'edit'
        NumUCI2BitsLabel
        NumUCI2BitsGUI

        DataSourceUCI2Type = 'popupmenu'
        DataSourceUCI2DropDown = {'PN9-ITU','PN9','PN11', 'PN15', 'PN23', 'User-defined'}
        DataSourceUCI2Label
        DataSourceUCI2GUI

        CustomDataSourceUCI2Type = 'edit'
        CustomDataSourceUCI2Label
        CustomDataSourceUCI2GUI

        DataSourceSRType = 'popupmenu'
        DataSourceSRDropDown = {'PN9-ITU','PN9','PN11', 'PN15', 'PN23', 'User-defined'}
        DataSourceSRLabel
        DataSourceSRGUI

        CustomDataSourceSRType = 'edit'
        CustomDataSourceSRLabel
        CustomDataSourceSRGUI
        
        TargetCodeRateType = 'edit'
        TargetCodeRateLabel
        TargetCodeRateGUI
    end

    methods
        function obj = nr5G_PUCCHUCI_Dialog(parent, fig)
            obj@wirelessWaveformGenerator.Dialog(parent, fig); % call base constructor

            % Callbacks needed either for validation of edit fields or for
            % changes to visibility of other controls
            obj.NumUCIBits_f01GUI.Callback           = @(a,b) numUCIBits_f01ChangedGUI(obj);
            obj.NumUCIBits_f2GUI.Callback            = @(a,b) numUCIBits_f2ChangedGUI(obj);
            obj.NumUCIBits_f34GUI.Callback           = @(a,b) numUCIBits_f34ChangedGUI(obj);
            obj.DataSourceUCI_f012GUI.Callback       = @(a,b) sourceUCI_f012ChangedGUI(obj);
            obj.CustomDataSourceUCI_f012GUI.Callback = @(a,b) customDataSourceUCI_f012ChangedGUI(obj);
            obj.DataSourceUCI_f34GUI.Callback        = @(a,b) sourceUCI_f34ChangedGUI(obj);
            obj.CustomDataSourceUCI_f34GUI.Callback  = @(a,b) customDataSourceUCI_f34ChangedGUI(obj);
            obj.NumUCI2BitsGUI.Callback              = @(a,b) numUCI2BitsChangedGUI(obj);
            obj.DataSourceUCI2GUI.Callback           = @(a,b) sourceUCI2ChangedGUI(obj);
            obj.CustomDataSourceUCI2GUI.Callback     = @(a,b) customDataSourceUCI2ChangedGUI(obj);
            obj.DataSourceSRGUI.Callback             = @(a,b) sourceSRChangedGUI(obj);
            obj.CustomDataSourceSRGUI.Callback       = @(a,b) customDataSourceSRChangedGUI(obj);
            obj.TargetCodeRateGUI.Callback           = @(a,b) codeRateChangedGUI(obj);
        end

        function adjustSpec(obj)
            % customization given the PUCCH max label length
            obj.LabelWidth = 150;
        end

        function adjustDialog(obj)
            % Make sure all tags are unique. Otherwise there is a conflict
            % with other channels
            obj.TargetCodeRateGUI.Tag = 'PUCCHTargetCodeRate';
            % Decorate the tags for the remaining properties with the
            % channel name
            obj.NumUCIBits_f01GUI.Tag = 'PUCCHNumUCIBits_f01';
            obj.NumUCIBits_f2GUI.Tag = 'PUCCHNumUCIBits_f2';
            obj.NumUCIBits_f34GUI.Tag = 'PUCCHNumUCIBits_f34';
            obj.DataSourceUCI_f012GUI.Tag = 'PUCCHDataSourceUCI_f012';
            obj.DataSourceUCI_f34GUI.Tag = 'PUCCHDataSourceUCI_f34';
            obj.CustomDataSourceUCI_f012GUI.Tag = 'PUCCHCustomDataSourceUCI_f012';
            obj.CustomDataSourceUCI_f34GUI.Tag = 'PUCCHCustomDataSourceUCI_f34';
            obj.DataSourceSRGUI.Tag = 'PUCCHDataSourceSR';
            obj.CustomDataSourceSRGUI.Tag = 'PUCCHCustomDataSourceSR';
            obj.NumUCI2BitsGUI.Tag = 'PUCCHNumUCI2Bits';
            obj.DataSourceUCI2GUI.Tag = 'PUCCHDataSourceUCI2';
            obj.CustomDataSourceUCI2GUI.Tag = 'PUCCHCustomDataSourceUCI2';
        end

        function props = displayOrder(~)
            props = {'NumUCIBits_f01'; 'NumUCIBits_f2'; 'DataSourceUCI_f012'; 'CustomDataSourceUCI_f012'; ...
                'NumUCIBits_f34'; 'DataSourceUCI_f34'; 'CustomDataSourceUCI_f34'; ...
                'NumUCI2Bits'; 'DataSourceUCI2'; 'CustomDataSourceUCI2'; ...
                'DataSourceSR'; 'CustomDataSourceSR'; 'TargetCodeRate'};
        end

        function restoreDefaults(obj)
            % Get the same defaults with programmatic objects
            c0 = nrWavegenPUCCH0Config;
            c2 = nrWavegenPUCCH2Config;
            c3 = nrWavegenPUCCH3Config;
            obj.NumUCIBits_f01           = c0.NumUCIBits;
            obj.NumUCIBits_f2            = c2.NumUCIBits;
            obj.NumUCIBits_f34           = c3.NumUCIBits;
            obj.NumUCI2Bits              = c3.NumUCI2Bits;
            obj.DataSourceUCI_f012       = c0.DataSourceUCI;
            obj.CustomDataSourceUCI_f012 = ones(obj.NumUCIBits_f01, 1);
            obj.DataSourceSR             = 'User-defined';
            obj.CustomDataSourceSR       = c0.DataSourceSR;
            obj.CustomDataSourceUCI_f34  = ones(obj.NumUCIBits_f34, 1);
            obj.CustomDataSourceUCI2     = 1;
            obj.TargetCodeRate           = 0.15;

            % Set default visibility
            formatChangedGUI(obj, 1);
            sourceUCI_f012ChangedGUI(obj, []); 
            sourceUCI_f34ChangedGUI(obj, []);
            sourceSRChangedGUI(obj, []);
        end

        function formatChangedGUI(obj,isNewRow)

            allProps = displayOrder(obj);
            switch obj.format
                case '0'
                    props = {'DataSourceUCI_f012', 'CustomDataSourceUCI_f012', 'NumUCIBits_f01', 'DataSourceSR', 'CustomDataSourceSR'};
                    
                    if isNewRow
                        % Assign the default values
                        c = nrWavegenPUCCH0Config;
                        obj.NumUCIBits_f01           = c.NumUCIBits;
                        obj.DataSourceUCI_f012       = c.DataSourceUCI;
                        obj.CustomDataSourceUCI_f012 = 1;
                        obj.DataSourceSR             = 'User-defined';
                        obj.CustomDataSourceSR       = c.DataSourceSR;
                    end
                    
                case '1'
                    props = {'DataSourceUCI_f012', 'CustomDataSourceUCI_f012', 'NumUCIBits_f01'};
                    
                    if isNewRow
                        % Assign the default values
                        c = nrWavegenPUCCH1Config;
                        obj.NumUCIBits_f01           = c.NumUCIBits;
                        obj.DataSourceUCI_f012       = c.DataSourceUCI;
                        obj.CustomDataSourceUCI_f012 = 1;
                    end
                    
                case '2'
                    props = {'DataSourceUCI_f012', 'CustomDataSourceUCI_f012', 'NumUCIBits_f2'};
                    
                    if isNewRow
                        % Assign the default values
                        c = nrWavegenPUCCH2Config;
                        obj.NumUCIBits_f2            = c.NumUCIBits;
                        obj.DataSourceUCI_f012       = c.DataSourceUCI;
                        obj.CustomDataSourceUCI_f012 = 1;
                    end

                otherwise % format 3 or 4
                    props = {'NumUCIBits_f34', 'DataSourceUCI_f34', 'CustomDataSourceUCI_f34', ...
                        'NumUCI2Bits', 'DataSourceUCI2', 'CustomDataSourceUCI2', 'TargetCodeRate'};
                    
                    if isNewRow
                        % Assign the default values
                        c = nrWavegenPUCCH3Config;
                        fnames = fieldnames(c);
                        fnames = fnames(ismember(fnames,props));
                        for n = 1:length(fnames)
                            obj.(fnames{n}) = c.(fnames{n});
                        end
                    end
            end
            
            % Make applicable properties visible
            for n = 1:length(props)
                set([obj.([props{n} 'Label']) obj.([props{n} 'GUI'])], ...
                    'Visible', uiservices.logicalToOnOff(true));
            end

            % Hide non-applicable properties
            notProps = allProps(~ismember(allProps,props));
            for n = 1:length(notProps)
                set([obj.([notProps{n} 'Label']) obj.([notProps{n} 'GUI'])], ...
                    'Visible', uiservices.logicalToOnOff(false));
            end
            
            % Adjust visibility for dependent properties
            if any(strcmp(obj.format, {'0', '1', '2'}))
                sourceUCI_f012ChangedGUI(obj, []);
                if strcmp(obj.format, '0')
                    sourceSRChangedGUI(obj, []);
                elseif strcmp(obj.format, '1')
                    numUCIBits_f01ChangedGUI(obj, []);
                end
            else % Format 3 or 4
                sourceUCI_f34ChangedGUI(obj, []);
                sourceUCI2ChangedGUI(obj, []);
                numUCI2BitsChangedGUI(obj, []);
            end

            % do re-layout only when it is needed, because it is expensive
            layoutUIControls(obj);
            layoutPanels(obj);

        end

        function numUCIBits_f01ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH0Config
                c = nrWavegenPUCCH0Config;
                c.NumUCIBits = obj.NumUCIBits_f01;
                validateConfig(c);
                if strcmp(obj.format, '1')
                    % Update the modulation scheme, if needed
                    className = 'wirelessWaveformGenerator.nr5G_PUCCHAdvanced_Dialog';
                    dlg = obj.Parent.WaveformGenerator.pParameters.DialogsMap(className);
                    if obj.NumUCIBits_f01==2
                        dlg.Modulation_f1 = 'QPSK';
                    else
                        dlg.Modulation_f1 = 'BPSK';
                    end
                    dlg.modChangedGUI(obj);
                end
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end
        
        function numUCIBits_f2ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH2Config
                c = nrWavegenPUCCH2Config;
                c.NumUCIBits = obj.NumUCIBits_f2;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end
        
        function numUCIBits_f34ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH3Config
                c = nrWavegenPUCCH3Config;
                c.NumUCIBits = obj.NumUCIBits_f34;
                if obj.NumUCIBits_f34 > 0
                    c.NumUCI2Bits = obj.NumUCI2Bits;
                end
                validateConfig(c);
                
                % UCI part 2 fields and TargetCodeRate appear only if NumUCIBits>0
                oldVis = strcmp(obj.NumUCI2BitsGUI.Visible, 'on');
                newVisUCI2 = obj.NumUCIBits_f34>0;
                newVisCustomUCI2 = newVisUCI2 && strcmpi(obj.DataSourceUCI2, 'User-defined');
                newVisCR = newVisUCI2 && obj.NumUCI2Bits>0;

                if xor(oldVis, newVisUCI2)
                    % do re-layout only when it is needed, because it is expensive
                    set([obj.NumUCI2BitsLabel obj.NumUCI2BitsGUI, ...
                         obj.DataSourceUCI2Label obj.DataSourceUCI2GUI], ...
                        'Visible', uiservices.logicaltoonoff(newVisUCI2));
                    set([obj.CustomDataSourceUCI2Label obj.CustomDataSourceUCI2GUI], ...
                        'Visible', uiservices.logicaltoonoff(newVisCustomUCI2));
                    set([obj.TargetCodeRateLabel obj.TargetCodeRateGUI], ...
                        'Visible', uiservices.logicaltoonoff(newVisCR));
                    layoutUIControls(obj);
                    layoutPanels(obj);
                end
                
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end

        function sourceUCI_f012ChangedGUI(obj, ~)
            % Custom data source edit field appears only under user-defined data
            % source for UCI
            oldVis = strcmp(obj.CustomDataSourceUCI_f012GUI.Visible, 'on');
            newVis = strcmpi(obj.DataSourceUCI_f012, 'User-defined');

            if xor(oldVis, newVis)
                % do re-layout only when it is needed, because it is expensive
                set([obj.CustomDataSourceUCI_f012Label obj.CustomDataSourceUCI_f012GUI], ...
                    'Visible', uiservices.logicaltoonoff(newVis));
                layoutUIControls(obj);
                layoutPanels(obj);
            end
        end
        
        function customDataSourceUCI_f012ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH0Config
                c = nrWavegenPUCCH0Config;
                c.DataSourceUCI = obj.CustomDataSourceUCI_f012;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end
        
        function sourceUCI_f34ChangedGUI(obj, ~)
            % Custom data source edit field appears only under user-defined data
            % source for UCI
            oldVis = strcmp(obj.CustomDataSourceUCI_f34GUI.Visible, 'on');
            newVis = strcmpi(obj.DataSourceUCI_f34, 'User-defined');

            if xor(oldVis, newVis)
                % do re-layout only when it is needed, because it is expensive
                set([obj.CustomDataSourceUCI_f34Label obj.CustomDataSourceUCI_f34GUI], ...
                    'Visible', uiservices.logicaltoonoff(newVis));
                layoutUIControls(obj);
                layoutPanels(obj);
            end
        end
        
        function customDataSourceUCI_f34ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH3Config
                c = nrWavegenPUCCH3Config;
                c.DataSourceUCI = obj.CustomDataSourceUCI_f34;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end

        function numUCI2BitsChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH3Config
                c = nrWavegenPUCCH3Config;
                c.NumUCIBits = obj.NumUCIBits_f34;
                c.NumUCI2Bits = obj.NumUCI2Bits;
                validateConfig(c);
                
                % TargetCodeRate appear only if NumUCI2Bits>0
                oldVis = strcmp(obj.TargetCodeRateGUI.Visible, 'on');
                newVis = obj.NumUCI2Bits>0;

                if xor(oldVis, newVis)
                    % do re-layout only when it is needed, because it is expensive
                    set([obj.TargetCodeRateLabel obj.TargetCodeRateGUI], ...
                        'Visible', uiservices.logicaltoonoff(newVis));
                    layoutUIControls(obj);
                    layoutPanels(obj);
                end
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end

        function sourceUCI2ChangedGUI(obj, ~)
            % Custom data source edit field appears only under user-defined data
            % source for UCI part 2
            oldVis = strcmp(obj.CustomDataSourceUCI2GUI.Visible, 'on');
            newVis = strcmpi(obj.DataSourceUCI2, 'User-defined');

            if xor(oldVis, newVis)
                % do re-layout only when it is needed, because it is expensive
                set([obj.CustomDataSourceUCI2Label obj.CustomDataSourceUCI2GUI], ...
                    'Visible', uiservices.logicaltoonoff(newVis));
                layoutUIControls(obj);
                layoutPanels(obj);
            end
        end
        
        function customDataSourceUCI2ChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH3Config
                c = nrWavegenPUCCH3Config;
                c.DataSourceUCI2 = obj.CustomDataSourceUCI2;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end
        
        function sourceSRChangedGUI(obj, ~)
            % Custom data source edit field appears only under user-defined data
            % source for SR
            oldVis = strcmp(obj.CustomDataSourceSRGUI.Visible, 'on');
            newVis = strcmpi(obj.DataSourceSR, 'User-defined');

            if xor(oldVis, newVis)
                % do re-layout only when it is needed, because it is expensive
                set([obj.CustomDataSourceSRLabel obj.CustomDataSourceSRGUI], ...
                    'Visible', uiservices.logicaltoonoff(newVis));
                layoutUIControls(obj);
                layoutPanels(obj);
            end
        end
        
        function customDataSourceSRChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH0Config
                c = nrWavegenPUCCH0Config;
                c.DataSourceSR = obj.CustomDataSourceSR;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end
        
        function codeRateChangedGUI(obj, ~)
            try
                % use error throwing behavior of nrWavegenPUCCH3Config
                c = nrWavegenPUCCH3Config;
                c.TargetCodeRate = obj.TargetCodeRate;
            catch e
                obj.errorFromException(e);
            end
            % Update message in status bar
            updateAppStatusBar(obj);
        end

        function updateAppStatusBar(obj)
            % Update the status bar to display any warning related to the current
            % configuration or to clear any previous warning that no longer apply
            dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
            updateStatusBar(dlg);
        end

        %% Getters/setters
        function n = get.NumUCIBits_f01(obj)
            n = str2double(obj.NumUCIBits_f01GUI.String{obj.NumUCIBits_f01GUI.Value});
        end
        function set.NumUCIBits_f01(obj, val)
            obj.NumUCIBits_f01GUI.Value = find(strcmp(obj.NumUCIBits_f01GUI.String, num2str(val)));
        end

        function n = get.NumUCIBits_f2(obj)
            n = evalin('base', obj.NumUCIBits_f2GUI.String);
        end
        function set.NumUCIBits_f2(obj, val)
            obj.NumUCIBits_f2GUI.String = num2str(val);
        end
        
        function n = get.NumUCIBits_f34(obj)
            n = evalin('base', obj.NumUCIBits_f34GUI.String);
        end
        function set.NumUCIBits_f34(obj, val)
            obj.NumUCIBits_f34GUI.String = num2str(val);
        end

        function fr = get.DataSourceUCI_f012(obj)
            fr = obj.DataSourceUCI_f012GUI.String{obj.DataSourceUCI_f012GUI.Value};
        end
        function set.DataSourceUCI_f012(obj, val)
            obj.DataSourceUCI_f012GUI.Value = find(strcmp(obj.DataSourceUCI_f012GUI.String, val));
        end

        function n = get.CustomDataSourceUCI_f012(obj)
            n = evalin('base', obj.CustomDataSourceUCI_f012GUI.String);
        end
        function set.CustomDataSourceUCI_f012(obj, val)
            obj.CustomDataSourceUCI_f012GUI.String = mat2str(val);
        end
        
        function fr = get.DataSourceUCI_f34(obj)
            fr = obj.DataSourceUCI_f34GUI.String{obj.DataSourceUCI_f34GUI.Value};
        end
        function set.DataSourceUCI_f34(obj, val)
            obj.DataSourceUCI_f34GUI.Value = find(strcmp(obj.DataSourceUCI_f34GUI.String, val));
        end

        function n = get.CustomDataSourceUCI_f34(obj)
            n = evalin('base', obj.CustomDataSourceUCI_f34GUI.String);
        end
        function set.CustomDataSourceUCI_f34(obj, val)
            obj.CustomDataSourceUCI_f34GUI.String = mat2str(val);
        end

        function n = get.NumUCI2Bits(obj)
            n = evalin('base', obj.NumUCI2BitsGUI.String);
        end
        function set.NumUCI2Bits(obj, val)
            obj.NumUCI2BitsGUI.String = num2str(val);
        end

        function fr = get.DataSourceUCI2(obj)
            fr = obj.DataSourceUCI2GUI.String{obj.DataSourceUCI2GUI.Value};
        end
        function set.DataSourceUCI2(obj, val)
            obj.DataSourceUCI2GUI.Value = find(strcmp(obj.DataSourceUCI2GUI.String, val));
        end

        function n = get.CustomDataSourceUCI2(obj)
            n = evalin('base', obj.CustomDataSourceUCI2GUI.String);
        end
        function set.CustomDataSourceUCI2(obj, val)
            obj.CustomDataSourceUCI2GUI.String = mat2str(val);
        end

        function fr = get.DataSourceSR(obj)
            fr = obj.DataSourceSRGUI.String{obj.DataSourceSRGUI.Value};
        end
        function set.DataSourceSR(obj, val)
            obj.DataSourceSRGUI.Value = find(strcmp(obj.DataSourceSRGUI.String, val));
        end

        function n = get.CustomDataSourceSR(obj)
            n = evalin('base', obj.CustomDataSourceSRGUI.String);
        end
        function set.CustomDataSourceSR(obj, val)
            obj.CustomDataSourceSRGUI.String = mat2str(val);
        end
        
        function n = get.TargetCodeRate(obj)
            n = evalin('base', obj.TargetCodeRateGUI.String);
        end
        function set.TargetCodeRate(obj, val)
            obj.TargetCodeRateGUI.String = num2str(val);
        end

        function str = getCatalogPrefix(~)
            str = 'nr5g:waveformGeneratorApp:';
        end

        function cellDialogs = getDialogsPerColumn(obj)
            cellDialogs{1} = {obj};
        end
    end
end
