classdef nr5G_PUSCHAdvanced_Dialog < wirelessWaveformGenerator.nr5G_PXSCHAdvanced_Dialog
% Interface to properties that are unique for PUSCH and are not present in the basic table

%   Copyright 2020-2021 The MathWorks, Inc.
  
	properties (Dependent)
    TransmissionScheme
    NumAntennaPorts
    TPMI
    FrequencyHopping
    SecondHopStartPRB
%     BetaOffsetACK
%     BetaOffsetCSI1
%     BetaOffsetCSI2
%     UCIScaling
%     DisableULSCH
  end  
  
  properties (Hidden)
    TitleString = 'PUSCH 1 (Advanced Configuration)'
    
    TransmissionSchemeType = 'popupmenu'
    TransmissionSchemeDropDown = {'nonCodebook', 'codebook'}
    TransmissionSchemeLabel
    TransmissionSchemeGUI
    
    NumAntennaPortsType = 'popupmenu'
    NumAntennaPortsDropDown = {'1', '2', '4'}
    NumAntennaPortsLabel
    NumAntennaPortsGUI
    
    TPMIType = 'edit'
    TPMILabel
    TPMIGUI
    
    FrequencyHoppingType = 'popupmenu'
    FrequencyHoppingDropDown = {'neither', 'intraSlot', 'interSlot'}
    FrequencyHoppingLabel
    FrequencyHoppingGUI
    
    SecondHopStartPRBType = 'edit'
    SecondHopStartPRBLabel
    SecondHopStartPRBGUI
    
%     BetaOffsetACKType = 'edit'
%     BetaOffsetACKLabel
%     BetaOffsetACKGUI
%     
%     BetaOffsetCSI1Type = 'edit'
%     BetaOffsetCSI1Label
%     BetaOffsetCSI1GUI
%     
%     BetaOffsetCSI2Type = 'edit'
%     BetaOffsetCSI2Label
%     BetaOffsetCSI2GUI
%     
%     UCIScalingType = 'popupmenu'
%     UCIScalingDropDown = {'0.5', '0.65', '0.8', '1'}
%     UCIScalingLabel
%     UCIScalingGUI
%
%     DisableULSCHType = 'checkbox'
%     DisableULSCHLabel
%     DisableULSCHGUI
  end
  
  methods
    function obj = nr5G_PUSCHAdvanced_Dialog(parent, fig)
      obj@wirelessWaveformGenerator.nr5G_PXSCHAdvanced_Dialog(parent, fig); % call base constructor
      
      % Callbacks needed either for validation of edit fields or for
      % changes to visibility of other controls
      obj.TPMIGUI.Callback                =  @(a,b) tpmiChangedGUI(obj);
      obj.SecondHopStartPRBGUI.Callback   =  @(a,b) secondHopChangedGUI(obj);
      obj.TransmissionSchemeGUI.Callback  =  @(a,b) txSchemeChangedGUI(obj);
      obj.FrequencyHoppingGUI.Callback    =  @(a,b) freqHopChangedGUI(obj);
%       obj.BetaOffsetACKGUI.Callback     =  @(a,b) betaACKChangedGUI(obj);
%       obj.BetaOffsetCSI1GUI.Callback    =  @(a,b) betaCSI1ChangedGUI(obj);
%       obj.BetaOffsetCSI2GUI.Callback    =  @(a,b) betaCSI2ChangedGUI(obj);
    end
    
    function adjustDialog(obj)
      % TPMI, NumAntennaPorts, SecondHopStart do not appear by default:
      set([obj.TPMILabel obj.TPMIGUI obj.NumAntennaPortsLabel obj.NumAntennaPortsGUI ...
           obj.SecondHopStartPRBLabel obj.SecondHopStartPRBGUI], ...
                 'Visible', 'off');
               
      % For test symmetry with PDSCH:
      obj.DataSourceGUI.Tag = 'PUSCHDataSource';
    end
        
    function props = displayOrder(~)
      props = {'Label'; 'TransmissionScheme'; ...
               'NumAntennaPorts'; 'TPMI'; 'FrequencyHopping'; 'SecondHopStartPRB'; ...  % 'BetaOffsetACK'; 'BetaOffsetCSI1'; 'BetaOffsetCSI2'; 'UCIScaling'; 
               'XOverhead';  'RVSequence'; ... %'DisableULSCH'; 
               'DataSource'; 'CustomDataSource'};
    end
    
    function restoreDefaults(obj)
      % Get the same defaults with programmatic objects
      c = nrWavegenPUSCHConfig;
      obj.Label               = c.Label;
      obj.RVSequence          = c.RVSequence;
      obj.TransmissionScheme  = c.TransmissionScheme;
      obj.NumAntennaPorts     = c.NumAntennaPorts;
      obj.TPMI                = c.TPMI;
      obj.FrequencyHopping    = c.FrequencyHopping;
      obj.SecondHopStartPRB   = c.SecondHopStartPRB;
%       obj.BetaOffsetACK = c.BetaOffsetACK;
%       obj.BetaOffsetCSI1 = c.BetaOffsetCSI1;
%       obj.BetaOffsetCSI2 = c.BetaOffsetCSI2;
%       obj.UCIScaling = c.UCIScaling;
%       obj.DisableULSCH = c.DisableULSCH;
      
      obj.XOverhead           = c.XOverhead;
      obj.DataSource          = c.DataSource;
      obj.CustomDataSource    = [1; 0; 0; 1];
    end
    
    function txSchemeChangedGUI(obj, ~)
      oldVis = strcmpi(obj.TPMIGUI.Visible, 'on');
      newVis = strcmpi(obj.TransmissionScheme, 'codebook');
      if xor(oldVis, newVis)
        set([obj.TPMILabel obj.TPMIGUI obj.NumAntennaPortsLabel obj.NumAntennaPortsGUI], ...
                 'Visible', uiservices.logicalToOnOff(newVis));
        
        % do re-layout only when it is needed, because it is expensive
        layoutUIControls(obj);
        layoutPanels(obj);
      end
    end
    
    function freqHopChangedGUI(obj, ~)
      oldVis = strcmpi(obj.SecondHopStartPRBGUI.Visible, 'on');
      newVis = ~strcmpi(obj.FrequencyHopping, 'neither');
      if xor(oldVis, newVis)
        set([obj.SecondHopStartPRBLabel obj.SecondHopStartPRBGUI], ...
                 'Visible', uiservices.logicalToOnOff(newVis));
        
        % do re-layout only when it is needed, because it is expensive
        layoutUIControls(obj);
        layoutPanels(obj);
      end
      
      % Do live grid update:
      updateGrids(obj);
    end
    
    function tpmiChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrWavegenPUSCHConfig
        c = nrWavegenPUSCHConfig;
        c.TPMI = obj.TPMI;
        
        % Do live grid update:
        updateGrids(obj);
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    
    function secondHopChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrWavegenPUSCHConfig
        c = nrWavegenPUSCHConfig;
        c.SecondHopStartPRB = obj.SecondHopStartPRB;
        
        % Do live grid update:
        updateGrids(obj);
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    
%     function betaACKChangedGUI(obj, ~)
%       try
%         % use error throwing behavior of nrWavegenPUSCHConfig
%         c = nrWavegenPUSCHConfig;
%         c.BetaOffsetACK = obj.BetaOffsetACK;
%         
%         % Do live grid update:
%         dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
%       catch e
%         obj.errorFromException(e);
%       end
%       % Update message in status bar
%       updateAppStatusBar(obj);
%     end
%     
%     function betaCSI1ChangedGUI(obj, ~)
%       try
%         % use error throwing behavior of nrWavegenPUSCHConfig
%         c = nrWavegenPUSCHConfig;
%         c.BetaOffsetCSI1 = obj.BetaOffsetCSI1;
%         
%         % Do live grid update:
%         dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
%       catch e
%         obj.errorFromException(e);
%       end
%       % Update message in status bar
%       updateAppStatusBar(obj);
%     end
%     
%     function betaCSI2ChangedGUI(obj, ~)
%       try
%         % use error throwing behavior of nrWavegenPUSCHConfig
%         c = nrWavegenPUSCHConfig;
%         c.BetaOffsetCSI2 = obj.BetaOffsetCSI2;
%         
%         % Do live grid update:
%         dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
%       catch e
%         obj.errorFromException(e);
%       end
%       % Update message in status bar
%       updateAppStatusBar(obj);
%     end
    
    % Getters/setters
    function fr = get.TransmissionScheme(obj) 
      fr = obj.TransmissionSchemeGUI.String{obj.TransmissionSchemeGUI.Value};
    end
    function set.TransmissionScheme(obj, val) 
      obj.TransmissionSchemeGUI.Value = find(strcmp(obj.TransmissionSchemeGUI.String, val)); 
    end
    
    function fr = get.NumAntennaPorts(obj) 
      fr = str2double(obj.NumAntennaPortsGUI.String{obj.NumAntennaPortsGUI.Value});
    end
    function set.NumAntennaPorts(obj, val) 
      obj.NumAntennaPortsGUI.Value = find(strcmp(obj.NumAntennaPortsGUI.String, num2str(val))); 
    end
    
    function n = get.TPMI(obj)
      n = evalin('base', obj.TPMIGUI.String);
    end
    function set.TPMI(obj, val)
      obj.TPMIGUI.String = num2str(val);
    end
    
    function fr = get.FrequencyHopping(obj) 
      fr = obj.FrequencyHoppingGUI.String{obj.FrequencyHoppingGUI.Value};
    end
    function set.FrequencyHopping(obj, val) 
      obj.FrequencyHoppingGUI.Value = find(strcmp(obj.FrequencyHoppingGUI.String, val)); 
    end
    
    function n = get.SecondHopStartPRB(obj)
      n = evalin('base', obj.SecondHopStartPRBGUI.String);
    end
    function set.SecondHopStartPRB(obj, val)
      obj.SecondHopStartPRBGUI.String = num2str(val);
    end
    
%     function n = get.BetaOffsetACK(obj)
%       n = evalin('base', obj.BetaOffsetACKGUI.String);
%     end
%     function set.BetaOffsetACK(obj, val)
%       obj.BetaOffsetACKGUI.String = num2str(val);
%     end
%     
%     function n = get.BetaOffsetCSI1(obj)
%       n = evalin('base', obj.BetaOffsetCSI1GUI.String);
%     end
%     function set.BetaOffsetCSI1(obj, val)
%       obj.BetaOffsetCSI1GUI.String = num2str(val);
%     end
%     
%     function n = get.BetaOffsetCSI2(obj)
%       n = evalin('base', obj.BetaOffsetCSI2GUI.String);
%     end
%     function set.BetaOffsetCSI2(obj, val)
%       obj.BetaOffsetCSI2GUI.String = num2str(val);
%     end
%     
%     function fr = get.UCIScaling(obj) 
%       fr = str2double(obj.UCIScalingGUI.String{obj.UCIScalingGUI.Value});
%     end
%     function set.UCIScaling(obj, val) 
%       obj.UCIScalingGUI.Value = find(strcmp(obj.UCIScalingGUI.String, num2str(val))); 
%     end
% 
%     function v = get.DisableULSCH(obj) 
%       v = logical(obj.DisableULSCHGUI.Value);
%     end
%     function set.DisableULSCH(obj, val) 
%       obj.DisableULSCHGUI.Value = val;
%     end
   
    % Stack Advanced/DMRS/PTRS vertically:
    function cellDialogs = getDialogsPerColumn(obj)
      cellDialogs{1} = {obj ...
        obj.Parent.WaveformGenerator.pParameters.DialogsMap('wirelessWaveformGenerator.nr5G_PUSCHDMRS_Dialog') ...
        obj.Parent.WaveformGenerator.pParameters.DialogsMap('wirelessWaveformGenerator.nr5G_PUSCHPTRS_Dialog') };
    end
  end
end
