classdef nr5G_PUSCHDMRS_Dialog < wirelessWaveformGenerator.nr5G_PXSCHDMRS_Dialog
% Interface to properties that are unique for PUSCH DMRS

%   Copyright 2020-2021 The MathWorks, Inc.
  
  properties (Dependent)
    GroupHopping
    SequenceHopping
    NRSID
  end  
  
  properties (Hidden)
    TitleString = 'PUSCH 1 DM-RS'    
    
    GroupHoppingType = 'checkbox'
    GroupHoppingLabel
    GroupHoppingGUI
    
    SequenceHoppingType = 'checkbox'
    SequenceHoppingLabel
    SequenceHoppingGUI
    
    NRSIDType = 'edit'    
    NRSIDLabel
    NRSIDGUI
  end
  
  methods
    function obj = nr5G_PUSCHDMRS_Dialog(parent, fig)
      obj@wirelessWaveformGenerator.nr5G_PXSCHDMRS_Dialog(parent, fig); % call base constructor
      
      % Callback needed either for validation of edit field
      obj.NRSIDGUI.Callback = @(a,b) nrsidChangedGUI(obj);
    end
    
    function adjustDialog(obj)
      % GroupHopping, SequenceHopping, and NRSID do not appear by default
      set([obj.GroupHoppingLabel obj.GroupHoppingGUI obj.SequenceHoppingLabel obj.SequenceHoppingGUI ...
           obj.NRSIDLabel obj.NRSIDGUI], 'Visible', 'off');
      
      % For test symmetry with PDSCH:
      obj.DMRSTypeAPositionGUI.Tag = 'PUSCHDMRSTypeAPosition';
    end
    
    function props = displayOrder(~)
      props = {'Power'; 'DMRSConfigurationType'; 'DMRSTypeAPosition';
              'DMRSAdditionalPosition'; 'DMRSLength'; 'CustomSymbolSet'; 
              'DMRSPortSet'; 'NIDNSCID'; 'NSCID'; 'GroupHopping'; ...
              'SequenceHopping'; 'NRSID'; 'NumCDMGroupsWithoutData'};
    end
    
    function restoreDefaults(obj)
      % Get the same defaults with programmatic objects
      c = nrWavegenPUSCHConfig;
      obj.Power                   = c.DMRSPower;
      
      c = nrPUSCHDMRSConfig;
      obj.DMRSConfigurationType   = c.DMRSConfigurationType;
      obj.DMRSTypeAPosition       = c.DMRSTypeAPosition;
      obj.DMRSAdditionalPosition  = c.DMRSAdditionalPosition;
      obj.DMRSLength              = c.DMRSLength;
      obj.CustomSymbolSet         = c.CustomSymbolSet;
      obj.DMRSPortSet             = c.DMRSPortSet;
      obj.NIDNSCID                = c.NIDNSCID;
      obj.NSCID                   = c.NSCID;
      obj.GroupHopping            = c.GroupHopping;
      obj.SequenceHopping         = c.SequenceHopping;
      obj.NRSID                   = c.NRSID;
      obj.NumCDMGroupsWithoutData = c.NumCDMGroupsWithoutData;
    end
    
    %% Validators
    function nrsidChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrPUSCHDMRSConfig
        c = nrPUSCHDMRSConfig;
        c.NRSID = obj.NRSID;
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    
    %% Getters/setters
    function v = get.GroupHopping(obj) 
      v = logical(obj.GroupHoppingGUI.Value);
    end
    function set.GroupHopping(obj, val) 
      obj.GroupHoppingGUI.Value = val;
    end
    
    function v = get.SequenceHopping(obj) 
      v = logical(obj.SequenceHoppingGUI.Value);
    end
    function set.SequenceHopping(obj, val) 
      obj.SequenceHoppingGUI.Value = val;
    end
    
    function n = get.NRSID(obj)
      n = evalin('base', obj.NRSIDGUI.String);
    end
    function set.NRSID(obj, val)
      obj.NRSIDGUI.String = mat2str(val);
    end
  end
end
