classdef nr5G_PXSCHDMRS_Dialog < wirelessWaveformGenerator.Dialog
% Interface to properties that are common for PXSCH DMRS

%   Copyright 2020-2021 The MathWorks, Inc.
  
  properties (Dependent)
    DMRSConfigurationType
    DMRSTypeAPosition
    DMRSAdditionalPosition
    DMRSLength
    CustomSymbolSet
    DMRSPortSet
    NIDNSCID
    NSCID
    NumCDMGroupsWithoutData
    Power
  end  
  
  properties (Hidden)
    configFcn = @struct
    
    DMRSConfigurationTypeType = 'popupmenu'
    DMRSConfigurationTypeDropDown = {'1', '2'}
    DMRSConfigurationTypeLabel
    DMRSConfigurationTypeGUI
    
    DMRSTypeAPositionType = 'popupmenu'
    DMRSTypeAPositionDropDown = {'2', '3'}
    DMRSTypeAPositionLabel
    DMRSTypeAPositionGUI
    
    DMRSAdditionalPositionType = 'popupmenu'
    DMRSAdditionalPositionDropDown = {'0', '1', '2', '3'}
    DMRSAdditionalPositionLabel
    DMRSAdditionalPositionGUI
    
    DMRSLengthType = 'popupmenu'
    DMRSLengthDropDown = {'1', '2'}
    DMRSLengthLabel
    DMRSLengthGUI
    
    CustomSymbolSetType = 'edit'    
    CustomSymbolSetLabel
    CustomSymbolSetGUI
   
    DMRSPortSetType = 'edit'    
    DMRSPortSetLabel
    DMRSPortSetGUI
    
    NIDNSCIDType = 'edit'    
    NIDNSCIDLabel
    NIDNSCIDGUI
    
    NSCIDType = 'popupmenu'    
    NSCIDDropDown = {'0', '1'}
    NSCIDLabel
    NSCIDGUI
        
    NumCDMGroupsWithoutDataType = 'popupmenu'
    NumCDMGroupsWithoutDataDropDown = {'1', '2', '3'}
    NumCDMGroupsWithoutDataLabel
    NumCDMGroupsWithoutDataGUI
    
    PowerType = 'edit'
    PowerGUI
    PowerLabel
  end
  
  methods
    function obj = nr5G_PXSCHDMRS_Dialog(parent, fig)
      obj@wirelessWaveformGenerator.Dialog(parent, fig); % call base constructor
      
      
      % Callbacks needed either for validation of edit fields or for grid
      % live update
      obj.PowerGUI.Callback                   = @(a,b) powerChangedGUI(obj);
      obj.CustomSymbolSetGUI.Callback         = @(a,b) customSymbolChangedGUI(obj);
      obj.DMRSPortSetGUI.Callback             = @(a,b) dmrsPortChangedGUI(obj);
      obj.NIDNSCIDGUI.Callback                = @(a,b) nidnscidChangedGUI(obj);
      obj.DMRSConfigurationTypeGUI.Callback   = @(a,b) dmrsGridChangedGUI(obj);
      obj.DMRSTypeAPositionGUI.Callback       = @(a,b) dmrsGridChangedGUI(obj);
      obj.DMRSAdditionalPositionGUI.Callback  = @(a,b) dmrsGridChangedGUI(obj);
      obj.DMRSLengthGUI.Callback              = @(a,b) dmrsGridChangedGUI(obj);
      obj.NumCDMGroupsWithoutDataGUI.Callback = @(a,b) dmrsGridChangedGUI(obj);
    end
    
    function adjustSpec(obj)
      % customization given the PXSCH max label length
      obj.LabelWidth = 150;
    end
    
    %% Validators
    function powerChangedGUI(obj)
      try
        % use error throwing behavior of nrWavegenPDSCHConfig
        c = nrWavegenPDSCHConfig;
        c.DMRSPower = obj.Power;
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    function customSymbolChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrPDSCHDMRSConfig
        c = nrPDSCHDMRSConfig;
        c.CustomSymbolSet = obj.CustomSymbolSet;
        dmrsGridChangedGUI(obj);
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    function dmrsPortChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrPDSCHDMRSConfig
        c = nrPDSCHDMRSConfig;
        c.DMRSPortSet = obj.DMRSPortSet;
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    function nidnscidChangedGUI(obj, ~)
      try
        % use error throwing behavior of nrPDSCHDMRSConfig
        c = nrPDSCHDMRSConfig;
        c.NIDNSCID = obj.NIDNSCID;
      catch e
        obj.errorFromException(e);
      end
      % Update message in status bar
      updateAppStatusBar(obj);
    end
    function dmrsGridChangedGUI(obj, ~)
        % A property that affects the DM-RS RE mapping is changed.
        % Do live RE mapping update:
        dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
        str = getTitle(obj);
        pxschID = extract(str,digitsPattern);
        channel = [str(1:length('PDSCH ')) pxschID{1}]; % channelName can be either PDSCH or PUSCH
        selectedRow = find(strcmp(pxschID,dlg.pxschTable.RowName)); % Get the row name ID
        dlg.updateREVisual(channel, selectedRow);

        % Do live grid update to trigger conflict detection:
        dlg.updateGrid();
    end

    function updateAppStatusBar(obj)
      % Update the status bar to display any warning related to the current
      % configuration or to clear any previous warning that no longer apply
      dlg = obj.Parent.WaveformGenerator.pParameters.CurrentDialog;
      updateStatusBar(dlg);
    end
    
    %% Getters/setters
    function fr = get.DMRSConfigurationType(obj) 
      fr = str2double(obj.DMRSConfigurationTypeGUI.String{obj.DMRSConfigurationTypeGUI.Value});
    end
    function set.DMRSConfigurationType(obj, val) 
      obj.DMRSConfigurationTypeGUI.Value = find(strcmp(obj.DMRSConfigurationTypeGUI.String, num2str(val))); 
    end
    
    function fr = get.DMRSTypeAPosition(obj) 
      fr = str2double(obj.DMRSTypeAPositionGUI.String{obj.DMRSTypeAPositionGUI.Value});
    end
    function set.DMRSTypeAPosition(obj, val) 
      obj.DMRSTypeAPositionGUI.Value = find(strcmp(obj.DMRSTypeAPositionGUI.String, num2str(val))); 
    end
    
    function fr = get.DMRSAdditionalPosition(obj) 
      fr = str2double(obj.DMRSAdditionalPositionGUI.String{obj.DMRSAdditionalPositionGUI.Value});
    end
    function set.DMRSAdditionalPosition(obj, val) 
      obj.DMRSAdditionalPositionGUI.Value = find(strcmp(obj.DMRSAdditionalPositionGUI.String, num2str(val))); 
    end
    
    function fr = get.DMRSLength(obj) 
      fr = str2double(obj.DMRSLengthGUI.String{obj.DMRSLengthGUI.Value});
    end
    function set.DMRSLength(obj, val) 
      obj.DMRSLengthGUI.Value = find(strcmp(obj.DMRSLengthGUI.String, num2str(val))); 
    end
    
    function fr = get.NumCDMGroupsWithoutData(obj) 
      fr = str2double(obj.NumCDMGroupsWithoutDataGUI.String{obj.NumCDMGroupsWithoutDataGUI.Value});
    end
    function set.NumCDMGroupsWithoutData(obj, val) 
      obj.NumCDMGroupsWithoutDataGUI.Value = find(strcmp(obj.NumCDMGroupsWithoutDataGUI.String, num2str(val))); 
    end
    
    function fr = get.NSCID(obj) 
      fr = str2double(obj.NSCIDGUI.String{obj.NSCIDGUI.Value});
    end
    function set.NSCID(obj, val) 
      obj.NSCIDGUI.Value = find(strcmp(obj.NSCIDGUI.String, num2str(val))); 
    end
    
    function n = get.CustomSymbolSet(obj)
      n = evalin('base', obj.CustomSymbolSetGUI.String);
    end
    function set.CustomSymbolSet(obj, val)
      obj.CustomSymbolSetGUI.String = mat2str(val);
    end
    
    function n = get.DMRSPortSet(obj)
      n = evalin('base', obj.DMRSPortSetGUI.String);
    end
    function set.DMRSPortSet(obj, val)
      obj.DMRSPortSetGUI.String = mat2str(val);
    end
        
    function n = get.NIDNSCID(obj)
      n = evalin('base', obj.NIDNSCIDGUI.String);
    end
    function set.NIDNSCID(obj, val)
      obj.NIDNSCIDGUI.String = mat2str(val);
    end
    
    function n = get.Power(obj)
      n = evalin('base', obj.PowerGUI.String);
    end
    function set.Power(obj, val)
      obj.PowerGUI.String = num2str(val);
    end
  
    function str = getCatalogPrefix(~)
      str = 'nr5g:waveformGeneratorApp:';
    end
    
    function cellDialogs = getDialogsPerColumn(obj)
      cellDialogs{1} = {obj};
    end
  end
end
