classdef nr5G_UL_InfoDialog < wirelessWaveformGenerator.Dialog
% Info panel for Uplink FRC extension

  %   Copyright 2018-2020 The MathWorks, Inc.
  
  properties (Dependent)
    SubcarrierSpacing
    AllocatedRBs
    Modulation
    TargetCodeRate
    NLayers
    TransformPrecodingInfo
    AllocatedSymbols
    PayloadSize
    DMRSConfigurationType
    PUSCHMappingType
    DMRSAdditionalPosition
    DMRSTypeAPosition
  end
  
  properties (Hidden)
    TitleString = getString(message('nr5g:waveformGeneratorApp:InfoTitle'))
    AllocatedSymbolsType = 'text'
    AllocatedSymbolsLabel
    AllocatedSymbolsGUI
    SubcarrierSpacingType = 'text'
    SubcarrierSpacingLabel
    SubcarrierSpacingGUI
    AllocatedRBsType = 'text'
    AllocatedRBsLabel
    AllocatedRBsGUI
    ModulationType = 'text'
    ModulationLabel
    ModulationGUI
    TargetCodeRateType = 'text'
    TargetCodeRateLabel
    TargetCodeRateGUI
    NLayersType = 'text'
    NLayersLabel
    NLayersGUI
    TransformPrecodingInfoType = 'text'
    TransformPrecodingInfoGUI
    TransformPrecodingInfoLabel
    PayloadSizeType = 'text'
    PayloadSizeLabel
    PayloadSizeGUI
    DMRSConfigurationTypeType = 'text'
    DMRSConfigurationTypeLabel
    DMRSConfigurationTypeGUI
    PUSCHMappingTypeType = 'text'
    PUSCHMappingTypeLabel
    PUSCHMappingTypeGUI
    DMRSAdditionalPositionType = 'text'
    DMRSAdditionalPositionLabel
    DMRSAdditionalPositionGUI
    DMRSTypeAPositionType = 'text'
    DMRSTypeAPositionLabel
    DMRSTypeAPositionGUI
    configFcn = @struct
  end
  
  methods
    function obj = nr5G_UL_InfoDialog(parent)
      obj@wirelessWaveformGenerator.Dialog(parent); % call base constructor

      setupDialog(obj); % layout controls
    end

    function restoreDefaults(obj)
      obj.AllocatedSymbolsGUI.String = ''; % so that mat2str doesn't yield ''''
      obj.SubcarrierSpacing = '';
      obj.AllocatedRBs = '';
      obj.Modulation = '';
      obj.TargetCodeRate = '';
      obj.PayloadSize = '';
      obj.DMRSConfigurationType = '';
      obj.PUSCHMappingType = '';
      obj.DMRSAdditionalPosition = '';
      obj.DMRSTypeAPosition = '';
    end
            
    function n = get.AllocatedSymbols(obj) 
      n = evalin('base', obj.AllocatedSymbolsGUI.String);
    end
    function set.AllocatedSymbols(obj, value) 
      obj.AllocatedSymbolsGUI.String = mat2str(value);
    end
    
    function n = get.SubcarrierSpacing(obj) 
      n = evalin('base', obj.SubcarrierSpacingGUI.String);
    end
    function set.SubcarrierSpacing(obj, value) 
      obj.SubcarrierSpacingGUI.String = num2str(value);
    end
    
    function n = get.AllocatedRBs(obj) 
      n = evalin('base', obj.AllocatedRBsGUI.String);
    end
    function set.AllocatedRBs(obj, value) 
      obj.AllocatedRBsGUI.String = num2str(value);
    end
    
    function n = get.Modulation(obj) 
      n = obj.ModulationGUI.String;
    end
    function set.Modulation(obj, value) 
      obj.ModulationGUI.String = value;
    end
    
    function n = get.TransformPrecodingInfo(obj) 
      n = obj.TransformPrecodingInfoGUI.String;
    end
    function set.TransformPrecodingInfo(obj, value) 
      obj.TransformPrecodingInfoGUI.String = value;
    end
    
    function n = get.TargetCodeRate(obj) 
      n = obj.TargetCodeRateGUI.String;
    end
    function set.TargetCodeRate(obj, value) 
      obj.TargetCodeRateGUI.String = num2str(value);
    end
    
    function n = get.NLayers(obj) 
      n = evalin('base', obj.NLayersGUI.String);
    end
    function set.NLayers(obj, value) 
      obj.NLayersGUI.String = num2str(value);
    end
    
    function n = get.PayloadSize(obj) 
      n = evalin('base', obj.PayloadSizeGUI.String);
    end
    function set.PayloadSize(obj, value) 
      obj.PayloadSizeGUI.String = num2str(value);
    end
    
    function n = get.DMRSConfigurationType(obj) 
      n = evalin('base', obj.DMRSConfigurationTypeGUI.String);
    end
    function set.DMRSConfigurationType(obj, value) 
      obj.DMRSConfigurationTypeGUI.String = num2str(value);
    end
    
    function n = get.PUSCHMappingType(obj) 
      n = evalin('base', obj.PUSCHMappingTypeGUI.String);
    end
    function set.PUSCHMappingType(obj, value) 
      obj.PUSCHMappingTypeGUI.String = num2str(value);
    end
    
    function n = get.DMRSAdditionalPosition(obj) 
      n = evalin('base', obj.DMRSAdditionalPositionGUI.String);
    end
    function set.DMRSAdditionalPosition(obj, value) 
      obj.DMRSAdditionalPositionGUI.String = num2str(value);
    end
    
    function n = get.DMRSTypeAPosition(obj) 
      n = evalin('base', obj.DMRSTypeAPositionGUI.String);
    end
    function set.DMRSTypeAPosition(obj, value) 
      obj.DMRSTypeAPositionGUI.String = num2str(value);
    end
    
    function msg = getMsgString(~, id, varargin)
	    msgID = ['nr5g:waveformGeneratorApp:' id];
	    msg = getString(message(msgID, varargin{:}));
	  end
  end
end